// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_CONST_RSC_A32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_CONST_RSC_A32_H_

const byte kInstruction_rsc_le_r9_r4_0x03fc0000[] = {
  0xff, 0x97, 0xe4, 0xd2 // rsc le r9 r4 0x03fc0000
};
const byte kInstruction_rsc_pl_r14_r3_0x0003fc00[] = {
  0xff, 0xeb, 0xe3, 0x52 // rsc pl r14 r3 0x0003fc00
};
const byte kInstruction_rsc_cc_r1_r6_0x3fc00000[] = {
  0xff, 0x15, 0xe6, 0x32 // rsc cc r1 r6 0x3fc00000
};
const byte kInstruction_rsc_cc_r5_r1_0x02ac0000[] = {
  0xab, 0x57, 0xe1, 0x32 // rsc cc r5 r1 0x02ac0000
};
const byte kInstruction_rsc_pl_r14_r4_0xb000000a[] = {
  0xab, 0xe2, 0xe4, 0x52 // rsc pl r14 r4 0xb000000a
};
const byte kInstruction_rsc_cs_r2_r13_0x0003fc00[] = {
  0xff, 0x2b, 0xed, 0x22 // rsc cs r2 r13 0x0003fc00
};
const byte kInstruction_rsc_mi_r13_r0_0x2ac00000[] = {
  0xab, 0xd5, 0xe0, 0x42 // rsc mi r13 r0 0x2ac00000
};
const byte kInstruction_rsc_vc_r0_r0_0x000ff000[] = {
  0xff, 0x0a, 0xe0, 0x72 // rsc vc r0 r0 0x000ff000
};
const byte kInstruction_rsc_vs_r2_r9_0x00000ff0[] = {
  0xff, 0x2e, 0xe9, 0x62 // rsc vs r2 r9 0x00000ff0
};
const byte kInstruction_rsc_cc_r15_r7_0x000000ff[] = {
  0xff, 0xf0, 0xe7, 0x32 // rsc cc r15 r7 0x000000ff
};
const byte kInstruction_rsc_ls_r4_r1_0x0003fc00[] = {
  0xff, 0x4b, 0xe1, 0x92 // rsc ls r4 r1 0x0003fc00
};
const byte kInstruction_rsc_gt_r13_r11_0x3fc00000[] = {
  0xff, 0xd5, 0xeb, 0xc2 // rsc gt r13 r11 0x3fc00000
};
const byte kInstruction_rsc_hi_r3_r15_0x2ac00000[] = {
  0xab, 0x35, 0xef, 0x82 // rsc hi r3 r15 0x2ac00000
};
const byte kInstruction_rsc_ls_r7_r12_0x02ac0000[] = {
  0xab, 0x77, 0xec, 0x92 // rsc ls r7 r12 0x02ac0000
};
const byte kInstruction_rsc_cc_r10_r11_0x00ab0000[] = {
  0xab, 0xa8, 0xeb, 0x32 // rsc cc r10 r11 0x00ab0000
};
const byte kInstruction_rsc_mi_r3_r9_0x03fc0000[] = {
  0xff, 0x37, 0xe9, 0x42 // rsc mi r3 r9 0x03fc0000
};
const byte kInstruction_rsc_gt_r8_r7_0x000ff000[] = {
  0xff, 0x8a, 0xe7, 0xc2 // rsc gt r8 r7 0x000ff000
};
const byte kInstruction_rsc_ls_r1_r2_0x00ab0000[] = {
  0xab, 0x18, 0xe2, 0x92 // rsc ls r1 r2 0x00ab0000
};
const byte kInstruction_rsc_al_r12_r5_0x00002ac0[] = {
  0xab, 0xcd, 0xe5, 0xe2 // rsc al r12 r5 0x00002ac0
};
const byte kInstruction_rsc_eq_r15_r5_0x000003fc[] = {
  0xff, 0xff, 0xe5, 0x02 // rsc eq r15 r5 0x000003fc
};
const byte kInstruction_rsc_hi_r11_r9_0x000000ab[] = {
  0xab, 0xb0, 0xe9, 0x82 // rsc hi r11 r9 0x000000ab
};
const byte kInstruction_rsc_cs_r10_r7_0x00ab0000[] = {
  0xab, 0xa8, 0xe7, 0x22 // rsc cs r10 r7 0x00ab0000
};
const byte kInstruction_rsc_gt_r3_r7_0x02ac0000[] = {
  0xab, 0x37, 0xe7, 0xc2 // rsc gt r3 r7 0x02ac0000
};
const byte kInstruction_rsc_le_r0_r0_0x00ab0000[] = {
  0xab, 0x08, 0xe0, 0xd2 // rsc le r0 r0 0x00ab0000
};
const byte kInstruction_rsc_hi_r15_r4_0x000000ab[] = {
  0xab, 0xf0, 0xe4, 0x82 // rsc hi r15 r4 0x000000ab
};
const byte kInstruction_rsc_cc_r4_r13_0xab000000[] = {
  0xab, 0x44, 0xed, 0x32 // rsc cc r4 r13 0xab000000
};
const byte kInstruction_rsc_al_r12_r2_0x0ab00000[] = {
  0xab, 0xc6, 0xe2, 0xe2 // rsc al r12 r2 0x0ab00000
};
const byte kInstruction_rsc_cc_r8_r1_0x000ff000[] = {
  0xff, 0x8a, 0xe1, 0x32 // rsc cc r8 r1 0x000ff000
};
const byte kInstruction_rsc_le_r1_r1_0x000ff000[] = {
  0xff, 0x1a, 0xe1, 0xd2 // rsc le r1 r1 0x000ff000
};
const byte kInstruction_rsc_gt_r3_r1_0xff000000[] = {
  0xff, 0x34, 0xe1, 0xc2 // rsc gt r3 r1 0xff000000
};
const byte kInstruction_rsc_ge_r4_r2_0x3fc00000[] = {
  0xff, 0x45, 0xe2, 0xa2 // rsc ge r4 r2 0x3fc00000
};
const byte kInstruction_rsc_cc_r8_r7_0xac000002[] = {
  0xab, 0x83, 0xe7, 0x32 // rsc cc r8 r7 0xac000002
};
const byte kInstruction_rsc_vs_r9_r4_0xb000000a[] = {
  0xab, 0x92, 0xe4, 0x62 // rsc vs r9 r4 0xb000000a
};
const byte kInstruction_rsc_cs_r11_r5_0x000000ab[] = {
  0xab, 0xb0, 0xe5, 0x22 // rsc cs r11 r5 0x000000ab
};
const byte kInstruction_rsc_eq_r4_r2_0xb000000a[] = {
  0xab, 0x42, 0xe2, 0x02 // rsc eq r4 r2 0xb000000a
};
const byte kInstruction_rsc_lt_r5_r14_0x000000ab[] = {
  0xab, 0x50, 0xee, 0xb2 // rsc lt r5 r14 0x000000ab
};
const byte kInstruction_rsc_cs_r2_r4_0x0000ab00[] = {
  0xab, 0x2c, 0xe4, 0x22 // rsc cs r2 r4 0x0000ab00
};
const byte kInstruction_rsc_hi_r5_r9_0x003fc000[] = {
  0xff, 0x59, 0xe9, 0x82 // rsc hi r5 r9 0x003fc000
};
const byte kInstruction_rsc_al_r0_r2_0xb000000a[] = {
  0xab, 0x02, 0xe2, 0xe2 // rsc al r0 r2 0xb000000a
};
const byte kInstruction_rsc_le_r13_r0_0x0ff00000[] = {
  0xff, 0xd6, 0xe0, 0xd2 // rsc le r13 r0 0x0ff00000
};
const byte kInstruction_rsc_eq_r9_r5_0xb000000a[] = {
  0xab, 0x92, 0xe5, 0x02 // rsc eq r9 r5 0xb000000a
};
const byte kInstruction_rsc_cc_r15_r8_0x00ab0000[] = {
  0xab, 0xf8, 0xe8, 0x32 // rsc cc r15 r8 0x00ab0000
};
const byte kInstruction_rsc_ge_r4_r3_0x003fc000[] = {
  0xff, 0x49, 0xe3, 0xa2 // rsc ge r4 r3 0x003fc000
};
const byte kInstruction_rsc_hi_r15_r1_0x000002ac[] = {
  0xab, 0xff, 0xe1, 0x82 // rsc hi r15 r1 0x000002ac
};
const byte kInstruction_rsc_al_r10_r8_0x000002ac[] = {
  0xab, 0xaf, 0xe8, 0xe2 // rsc al r10 r8 0x000002ac
};
const byte kInstruction_rsc_al_r3_r5_0xc000003f[] = {
  0xff, 0x31, 0xe5, 0xe2 // rsc al r3 r5 0xc000003f
};
const byte kInstruction_rsc_cc_r1_r8_0x000000ff[] = {
  0xff, 0x10, 0xe8, 0x32 // rsc cc r1 r8 0x000000ff
};
const byte kInstruction_rsc_vs_r8_r4_0x003fc000[] = {
  0xff, 0x89, 0xe4, 0x62 // rsc vs r8 r4 0x003fc000
};
const byte kInstruction_rsc_vc_r2_r2_0x003fc000[] = {
  0xff, 0x29, 0xe2, 0x72 // rsc vc r2 r2 0x003fc000
};
const byte kInstruction_rsc_hi_r1_r1_0x03fc0000[] = {
  0xff, 0x17, 0xe1, 0x82 // rsc hi r1 r1 0x03fc0000
};
const byte kInstruction_rsc_cc_r6_r12_0x00000000[] = {
  0x00, 0x60, 0xec, 0x32 // rsc cc r6 r12 0x00000000
};
const byte kInstruction_rsc_hi_r8_r1_0xc000002a[] = {
  0xab, 0x81, 0xe1, 0x82 // rsc hi r8 r1 0xc000002a
};
const byte kInstruction_rsc_ge_r7_r12_0x003fc000[] = {
  0xff, 0x79, 0xec, 0xa2 // rsc ge r7 r12 0x003fc000
};
const byte kInstruction_rsc_gt_r1_r14_0x02ac0000[] = {
  0xab, 0x17, 0xee, 0xc2 // rsc gt r1 r14 0x02ac0000
};
const byte kInstruction_rsc_eq_r4_r0_0x0ff00000[] = {
  0xff, 0x46, 0xe0, 0x02 // rsc eq r4 r0 0x0ff00000
};
const byte kInstruction_rsc_vs_r6_r10_0x00000ab0[] = {
  0xab, 0x6e, 0xea, 0x62 // rsc vs r6 r10 0x00000ab0
};
const byte kInstruction_rsc_eq_r4_r8_0x03fc0000[] = {
  0xff, 0x47, 0xe8, 0x02 // rsc eq r4 r8 0x03fc0000
};
const byte kInstruction_rsc_lt_r8_r13_0x002ac000[] = {
  0xab, 0x89, 0xed, 0xb2 // rsc lt r8 r13 0x002ac000
};
const byte kInstruction_rsc_mi_r1_r5_0x000003fc[] = {
  0xff, 0x1f, 0xe5, 0x42 // rsc mi r1 r5 0x000003fc
};
const byte kInstruction_rsc_ge_r8_r1_0x00ab0000[] = {
  0xab, 0x88, 0xe1, 0xa2 // rsc ge r8 r1 0x00ab0000
};
const byte kInstruction_rsc_al_r0_r8_0xb000000a[] = {
  0xab, 0x02, 0xe8, 0xe2 // rsc al r0 r8 0xb000000a
};
const byte kInstruction_rsc_cs_r3_r0_0x0000ff00[] = {
  0xff, 0x3c, 0xe0, 0x22 // rsc cs r3 r0 0x0000ff00
};
const byte kInstruction_rsc_le_r14_r6_0x03fc0000[] = {
  0xff, 0xe7, 0xe6, 0xd2 // rsc le r14 r6 0x03fc0000
};
const byte kInstruction_rsc_lt_r13_r7_0xab000000[] = {
  0xab, 0xd4, 0xe7, 0xb2 // rsc lt r13 r7 0xab000000
};
const byte kInstruction_rsc_vc_r7_r7_0x00ff0000[] = {
  0xff, 0x78, 0xe7, 0x72 // rsc vc r7 r7 0x00ff0000
};
const byte kInstruction_rsc_ls_r8_r1_0x0ab00000[] = {
  0xab, 0x86, 0xe1, 0x92 // rsc ls r8 r1 0x0ab00000
};
const byte kInstruction_rsc_lt_r10_r12_0x000002ac[] = {
  0xab, 0xaf, 0xec, 0xb2 // rsc lt r10 r12 0x000002ac
};
const byte kInstruction_rsc_ls_r11_r0_0x3fc00000[] = {
  0xff, 0xb5, 0xe0, 0x92 // rsc ls r11 r0 0x3fc00000
};
const byte kInstruction_rsc_ge_r9_r8_0x002ac000[] = {
  0xab, 0x99, 0xe8, 0xa2 // rsc ge r9 r8 0x002ac000
};
const byte kInstruction_rsc_vc_r5_r2_0x02ac0000[] = {
  0xab, 0x57, 0xe2, 0x72 // rsc vc r5 r2 0x02ac0000
};
const byte kInstruction_rsc_gt_r2_r9_0x0ff00000[] = {
  0xff, 0x26, 0xe9, 0xc2 // rsc gt r2 r9 0x0ff00000
};
const byte kInstruction_rsc_eq_r10_r6_0x2ac00000[] = {
  0xab, 0xa5, 0xe6, 0x02 // rsc eq r10 r6 0x2ac00000
};
const byte kInstruction_rsc_ls_r0_r9_0xfc000003[] = {
  0xff, 0x03, 0xe9, 0x92 // rsc ls r0 r9 0xfc000003
};
const byte kInstruction_rsc_eq_r15_r12_0x02ac0000[] = {
  0xab, 0xf7, 0xec, 0x02 // rsc eq r15 r12 0x02ac0000
};
const byte kInstruction_rsc_mi_r3_r1_0xfc000003[] = {
  0xff, 0x33, 0xe1, 0x42 // rsc mi r3 r1 0xfc000003
};
const byte kInstruction_rsc_lt_r0_r0_0xb000000a[] = {
  0xab, 0x02, 0xe0, 0xb2 // rsc lt r0 r0 0xb000000a
};
const byte kInstruction_rsc_cs_r14_r8_0xff000000[] = {
  0xff, 0xe4, 0xe8, 0x22 // rsc cs r14 r8 0xff000000
};
const byte kInstruction_rsc_lt_r7_r1_0x00003fc0[] = {
  0xff, 0x7d, 0xe1, 0xb2 // rsc lt r7 r1 0x00003fc0
};
const byte kInstruction_rsc_ls_r8_r1_0x00000ff0[] = {
  0xff, 0x8e, 0xe1, 0x92 // rsc ls r8 r1 0x00000ff0
};
const byte kInstruction_rsc_cc_r15_r3_0x0002ac00[] = {
  0xab, 0xfb, 0xe3, 0x32 // rsc cc r15 r3 0x0002ac00
};
const byte kInstruction_rsc_cs_r15_r0_0xc000003f[] = {
  0xff, 0xf1, 0xe0, 0x22 // rsc cs r15 r0 0xc000003f
};
const byte kInstruction_rsc_hi_r4_r2_0x0002ac00[] = {
  0xab, 0x4b, 0xe2, 0x82 // rsc hi r4 r2 0x0002ac00
};
const byte kInstruction_rsc_ne_r10_r12_0x0003fc00[] = {
  0xff, 0xab, 0xec, 0x12 // rsc ne r10 r12 0x0003fc00
};
const byte kInstruction_rsc_gt_r7_r13_0x00003fc0[] = {
  0xff, 0x7d, 0xed, 0xc2 // rsc gt r7 r13 0x00003fc0
};
const byte kInstruction_rsc_vc_r14_r4_0xac000002[] = {
  0xab, 0xe3, 0xe4, 0x72 // rsc vc r14 r4 0xac000002
};
const byte kInstruction_rsc_le_r13_r7_0x00000000[] = {
  0x00, 0xd0, 0xe7, 0xd2 // rsc le r13 r7 0x00000000
};
const byte kInstruction_rsc_pl_r5_r15_0x00000ab0[] = {
  0xab, 0x5e, 0xef, 0x52 // rsc pl r5 r15 0x00000ab0
};
const byte kInstruction_rsc_vs_r1_r1_0x03fc0000[] = {
  0xff, 0x17, 0xe1, 0x62 // rsc vs r1 r1 0x03fc0000
};
const byte kInstruction_rsc_le_r4_r4_0xab000000[] = {
  0xab, 0x44, 0xe4, 0xd2 // rsc le r4 r4 0xab000000
};
const byte kInstruction_rsc_gt_r11_r4_0x0ff00000[] = {
  0xff, 0xb6, 0xe4, 0xc2 // rsc gt r11 r4 0x0ff00000
};
const byte kInstruction_rsc_cc_r1_r3_0x0000ab00[] = {
  0xab, 0x1c, 0xe3, 0x32 // rsc cc r1 r3 0x0000ab00
};
const byte kInstruction_rsc_cs_r10_r9_0x0000ab00[] = {
  0xab, 0xac, 0xe9, 0x22 // rsc cs r10 r9 0x0000ab00
};
const byte kInstruction_rsc_vc_r7_r5_0x00ab0000[] = {
  0xab, 0x78, 0xe5, 0x72 // rsc vc r7 r5 0x00ab0000
};
const byte kInstruction_rsc_cc_r4_r1_0x0000ab00[] = {
  0xab, 0x4c, 0xe1, 0x32 // rsc cc r4 r1 0x0000ab00
};
const byte kInstruction_rsc_hi_r4_r15_0xfc000003[] = {
  0xff, 0x43, 0xef, 0x82 // rsc hi r4 r15 0xfc000003
};
const byte kInstruction_rsc_eq_r11_r1_0xff000000[] = {
  0xff, 0xb4, 0xe1, 0x02 // rsc eq r11 r1 0xff000000
};
const byte kInstruction_rsc_gt_r4_r2_0x00002ac0[] = {
  0xab, 0x4d, 0xe2, 0xc2 // rsc gt r4 r2 0x00002ac0
};
const byte kInstruction_rsc_ls_r10_r10_0x000000ff[] = {
  0xff, 0xa0, 0xea, 0x92 // rsc ls r10 r10 0x000000ff
};
const byte kInstruction_rsc_gt_r11_r10_0x00ff0000[] = {
  0xff, 0xb8, 0xea, 0xc2 // rsc gt r11 r10 0x00ff0000
};
const byte kInstruction_rsc_ls_r12_r6_0x00000ff0[] = {
  0xff, 0xce, 0xe6, 0x92 // rsc ls r12 r6 0x00000ff0
};
const byte kInstruction_rsc_vc_r9_r4_0xb000000a[] = {
  0xab, 0x92, 0xe4, 0x72 // rsc vc r9 r4 0xb000000a
};
const byte kInstruction_rsc_hi_r10_r13_0x00003fc0[] = {
  0xff, 0xad, 0xed, 0x82 // rsc hi r10 r13 0x00003fc0
};
const byte kInstruction_rsc_vc_r6_r4_0xab000000[] = {
  0xab, 0x64, 0xe4, 0x72 // rsc vc r6 r4 0xab000000
};
const byte kInstruction_rsc_gt_r1_r4_0x0ff00000[] = {
  0xff, 0x16, 0xe4, 0xc2 // rsc gt r1 r4 0x0ff00000
};
const byte kInstruction_rsc_ne_r8_r0_0x00003fc0[] = {
  0xff, 0x8d, 0xe0, 0x12 // rsc ne r8 r0 0x00003fc0
};
const byte kInstruction_rsc_ls_r13_r9_0x0002ac00[] = {
  0xab, 0xdb, 0xe9, 0x92 // rsc ls r13 r9 0x0002ac00
};
const byte kInstruction_rsc_eq_r8_r8_0xfc000003[] = {
  0xff, 0x83, 0xe8, 0x02 // rsc eq r8 r8 0xfc000003
};
const byte kInstruction_rsc_pl_r4_r3_0x0002ac00[] = {
  0xab, 0x4b, 0xe3, 0x52 // rsc pl r4 r3 0x0002ac00
};
const byte kInstruction_rsc_cc_r3_r1_0xab000000[] = {
  0xab, 0x34, 0xe1, 0x32 // rsc cc r3 r1 0xab000000
};
const byte kInstruction_rsc_cc_r13_r3_0xc000002a[] = {
  0xab, 0xd1, 0xe3, 0x32 // rsc cc r13 r3 0xc000002a
};
const byte kInstruction_rsc_cc_r10_r14_0x00000000[] = {
  0x00, 0xa0, 0xee, 0x32 // rsc cc r10 r14 0x00000000
};
const byte kInstruction_rsc_hi_r13_r6_0x000ff000[] = {
  0xff, 0xda, 0xe6, 0x82 // rsc hi r13 r6 0x000ff000
};
const byte kInstruction_rsc_ge_r7_r15_0x0002ac00[] = {
  0xab, 0x7b, 0xef, 0xa2 // rsc ge r7 r15 0x0002ac00
};
const byte kInstruction_rsc_le_r1_r11_0x0002ac00[] = {
  0xab, 0x1b, 0xeb, 0xd2 // rsc le r1 r11 0x0002ac00
};
const byte kInstruction_rsc_gt_r12_r1_0x02ac0000[] = {
  0xab, 0xc7, 0xe1, 0xc2 // rsc gt r12 r1 0x02ac0000
};
const byte kInstruction_rsc_hi_r0_r12_0x00002ac0[] = {
  0xab, 0x0d, 0xec, 0x82 // rsc hi r0 r12 0x00002ac0
};
const byte kInstruction_rsc_lt_r6_r9_0xfc000003[] = {
  0xff, 0x63, 0xe9, 0xb2 // rsc lt r6 r9 0xfc000003
};
const byte kInstruction_rsc_ls_r6_r6_0x0002ac00[] = {
  0xab, 0x6b, 0xe6, 0x92 // rsc ls r6 r6 0x0002ac00
};
const byte kInstruction_rsc_vc_r12_r3_0xab000000[] = {
  0xab, 0xc4, 0xe3, 0x72 // rsc vc r12 r3 0xab000000
};
const byte kInstruction_rsc_pl_r12_r10_0x0ab00000[] = {
  0xab, 0xc6, 0xea, 0x52 // rsc pl r12 r10 0x0ab00000
};
const byte kInstruction_rsc_lt_r9_r11_0xff000000[] = {
  0xff, 0x94, 0xeb, 0xb2 // rsc lt r9 r11 0xff000000
};
const byte kInstruction_rsc_pl_r1_r11_0x00000ff0[] = {
  0xff, 0x1e, 0xeb, 0x52 // rsc pl r1 r11 0x00000ff0
};
const byte kInstruction_rsc_cs_r10_r3_0x00003fc0[] = {
  0xff, 0xad, 0xe3, 0x22 // rsc cs r10 r3 0x00003fc0
};
const byte kInstruction_rsc_vs_r1_r12_0x03fc0000[] = {
  0xff, 0x17, 0xec, 0x62 // rsc vs r1 r12 0x03fc0000
};
const byte kInstruction_rsc_ls_r2_r2_0xf000000f[] = {
  0xff, 0x22, 0xe2, 0x92 // rsc ls r2 r2 0xf000000f
};
const byte kInstruction_rsc_pl_r11_r4_0x0003fc00[] = {
  0xff, 0xbb, 0xe4, 0x52 // rsc pl r11 r4 0x0003fc00
};
const byte kInstruction_rsc_cc_r13_r7_0x03fc0000[] = {
  0xff, 0xd7, 0xe7, 0x32 // rsc cc r13 r7 0x03fc0000
};
const byte kInstruction_rsc_hi_r5_r1_0x00ab0000[] = {
  0xab, 0x58, 0xe1, 0x82 // rsc hi r5 r1 0x00ab0000
};
const byte kInstruction_rsc_eq_r8_r5_0x0ab00000[] = {
  0xab, 0x86, 0xe5, 0x02 // rsc eq r8 r5 0x0ab00000
};
const byte kInstruction_rsc_ge_r6_r15_0x0002ac00[] = {
  0xab, 0x6b, 0xef, 0xa2 // rsc ge r6 r15 0x0002ac00
};
const byte kInstruction_rsc_ls_r5_r6_0x00000ff0[] = {
  0xff, 0x5e, 0xe6, 0x92 // rsc ls r5 r6 0x00000ff0
};
const byte kInstruction_rsc_gt_r13_r11_0x000003fc[] = {
  0xff, 0xdf, 0xeb, 0xc2 // rsc gt r13 r11 0x000003fc
};
const byte kInstruction_rsc_vc_r8_r6_0xc000002a[] = {
  0xab, 0x81, 0xe6, 0x72 // rsc vc r8 r6 0xc000002a
};
const byte kInstruction_rsc_ge_r10_r2_0x000000ab[] = {
  0xab, 0xa0, 0xe2, 0xa2 // rsc ge r10 r2 0x000000ab
};
const byte kInstruction_rsc_pl_r7_r14_0x000000ab[] = {
  0xab, 0x70, 0xee, 0x52 // rsc pl r7 r14 0x000000ab
};
const byte kInstruction_rsc_vc_r11_r10_0x3fc00000[] = {
  0xff, 0xb5, 0xea, 0x72 // rsc vc r11 r10 0x3fc00000
};
const byte kInstruction_rsc_pl_r9_r0_0x00003fc0[] = {
  0xff, 0x9d, 0xe0, 0x52 // rsc pl r9 r0 0x00003fc0
};
const byte kInstruction_rsc_hi_r15_r1_0x000ab000[] = {
  0xab, 0xfa, 0xe1, 0x82 // rsc hi r15 r1 0x000ab000
};
const byte kInstruction_rsc_gt_r3_r4_0x00ab0000[] = {
  0xab, 0x38, 0xe4, 0xc2 // rsc gt r3 r4 0x00ab0000
};
const byte kInstruction_rsc_cs_r7_r12_0x00000ab0[] = {
  0xab, 0x7e, 0xec, 0x22 // rsc cs r7 r12 0x00000ab0
};
const byte kInstruction_rsc_vs_r3_r8_0x0ff00000[] = {
  0xff, 0x36, 0xe8, 0x62 // rsc vs r3 r8 0x0ff00000
};
const byte kInstruction_rsc_cc_r12_r8_0x000000ff[] = {
  0xff, 0xc0, 0xe8, 0x32 // rsc cc r12 r8 0x000000ff
};
const byte kInstruction_rsc_vc_r1_r5_0x02ac0000[] = {
  0xab, 0x17, 0xe5, 0x72 // rsc vc r1 r5 0x02ac0000
};
const byte kInstruction_rsc_cc_r7_r12_0xf000000f[] = {
  0xff, 0x72, 0xec, 0x32 // rsc cc r7 r12 0xf000000f
};
const byte kInstruction_rsc_gt_r9_r4_0x0000ab00[] = {
  0xab, 0x9c, 0xe4, 0xc2 // rsc gt r9 r4 0x0000ab00
};
const byte kInstruction_rsc_pl_r14_r8_0x0ff00000[] = {
  0xff, 0xe6, 0xe8, 0x52 // rsc pl r14 r8 0x0ff00000
};
const byte kInstruction_rsc_vc_r8_r4_0x000003fc[] = {
  0xff, 0x8f, 0xe4, 0x72 // rsc vc r8 r4 0x000003fc
};
const byte kInstruction_rsc_cc_r1_r15_0xb000000a[] = {
  0xab, 0x12, 0xef, 0x32 // rsc cc r1 r15 0xb000000a
};
const byte kInstruction_rsc_al_r15_r11_0x000ff000[] = {
  0xff, 0xfa, 0xeb, 0xe2 // rsc al r15 r11 0x000ff000
};
const byte kInstruction_rsc_ls_r1_r13_0x00002ac0[] = {
  0xab, 0x1d, 0xed, 0x92 // rsc ls r1 r13 0x00002ac0
};
const byte kInstruction_rsc_le_r4_r10_0x03fc0000[] = {
  0xff, 0x47, 0xea, 0xd2 // rsc le r4 r10 0x03fc0000
};
const byte kInstruction_rsc_mi_r2_r4_0x00000ab0[] = {
  0xab, 0x2e, 0xe4, 0x42 // rsc mi r2 r4 0x00000ab0
};
const byte kInstruction_rsc_al_r13_r6_0x02ac0000[] = {
  0xab, 0xd7, 0xe6, 0xe2 // rsc al r13 r6 0x02ac0000
};
const byte kInstruction_rsc_mi_r7_r9_0x000002ac[] = {
  0xab, 0x7f, 0xe9, 0x42 // rsc mi r7 r9 0x000002ac
};
const byte kInstruction_rsc_hi_r9_r7_0x00002ac0[] = {
  0xab, 0x9d, 0xe7, 0x82 // rsc hi r9 r7 0x00002ac0
};
const byte kInstruction_rsc_vc_r15_r9_0x0000ab00[] = {
  0xab, 0xfc, 0xe9, 0x72 // rsc vc r15 r9 0x0000ab00
};
const byte kInstruction_rsc_vc_r13_r0_0xff000000[] = {
  0xff, 0xd4, 0xe0, 0x72 // rsc vc r13 r0 0xff000000
};
const byte kInstruction_rsc_cc_r15_r10_0x00003fc0[] = {
  0xff, 0xfd, 0xea, 0x32 // rsc cc r15 r10 0x00003fc0
};
const byte kInstruction_rsc_lt_r12_r2_0x00000ab0[] = {
  0xab, 0xce, 0xe2, 0xb2 // rsc lt r12 r2 0x00000ab0
};
const byte kInstruction_rsc_le_r1_r3_0xb000000a[] = {
  0xab, 0x12, 0xe3, 0xd2 // rsc le r1 r3 0xb000000a
};
const byte kInstruction_rsc_hi_r14_r12_0xc000002a[] = {
  0xab, 0xe1, 0xec, 0x82 // rsc hi r14 r12 0xc000002a
};
const byte kInstruction_rsc_vc_r5_r8_0x000ff000[] = {
  0xff, 0x5a, 0xe8, 0x72 // rsc vc r5 r8 0x000ff000
};
const byte kInstruction_rsc_gt_r12_r9_0x000000ab[] = {
  0xab, 0xc0, 0xe9, 0xc2 // rsc gt r12 r9 0x000000ab
};
const byte kInstruction_rsc_al_r13_r7_0xf000000f[] = {
  0xff, 0xd2, 0xe7, 0xe2 // rsc al r13 r7 0xf000000f
};
const byte kInstruction_rsc_ls_r3_r10_0x000002ac[] = {
  0xab, 0x3f, 0xea, 0x92 // rsc ls r3 r10 0x000002ac
};
const byte kInstruction_rsc_ne_r13_r13_0x00000ab0[] = {
  0xab, 0xde, 0xed, 0x12 // rsc ne r13 r13 0x00000ab0
};
const byte kInstruction_rsc_ge_r15_r3_0xfc000003[] = {
  0xff, 0xf3, 0xe3, 0xa2 // rsc ge r15 r3 0xfc000003
};
const byte kInstruction_rsc_cc_r7_r0_0x0003fc00[] = {
  0xff, 0x7b, 0xe0, 0x32 // rsc cc r7 r0 0x0003fc00
};
const byte kInstruction_rsc_eq_r3_r14_0x2ac00000[] = {
  0xab, 0x35, 0xee, 0x02 // rsc eq r3 r14 0x2ac00000
};
const byte kInstruction_rsc_al_r11_r14_0x003fc000[] = {
  0xff, 0xb9, 0xee, 0xe2 // rsc al r11 r14 0x003fc000
};
const byte kInstruction_rsc_gt_r3_r12_0x02ac0000[] = {
  0xab, 0x37, 0xec, 0xc2 // rsc gt r3 r12 0x02ac0000
};
const byte kInstruction_rsc_mi_r7_r15_0xac000002[] = {
  0xab, 0x73, 0xef, 0x42 // rsc mi r7 r15 0xac000002
};
const byte kInstruction_rsc_al_r3_r2_0x002ac000[] = {
  0xab, 0x39, 0xe2, 0xe2 // rsc al r3 r2 0x002ac000
};
const byte kInstruction_rsc_hi_r2_r6_0x0002ac00[] = {
  0xab, 0x2b, 0xe6, 0x82 // rsc hi r2 r6 0x0002ac00
};
const byte kInstruction_rsc_eq_r8_r5_0x03fc0000[] = {
  0xff, 0x87, 0xe5, 0x02 // rsc eq r8 r5 0x03fc0000
};
const byte kInstruction_rsc_hi_r2_r13_0x0002ac00[] = {
  0xab, 0x2b, 0xed, 0x82 // rsc hi r2 r13 0x0002ac00
};
const byte kInstruction_rsc_lt_r10_r10_0x00ab0000[] = {
  0xab, 0xa8, 0xea, 0xb2 // rsc lt r10 r10 0x00ab0000
};
const byte kInstruction_rsc_al_r12_r3_0x0ab00000[] = {
  0xab, 0xc6, 0xe3, 0xe2 // rsc al r12 r3 0x0ab00000
};
const byte kInstruction_rsc_ls_r1_r2_0x003fc000[] = {
  0xff, 0x19, 0xe2, 0x92 // rsc ls r1 r2 0x003fc000
};
const byte kInstruction_rsc_le_r9_r10_0x000ff000[] = {
  0xff, 0x9a, 0xea, 0xd2 // rsc le r9 r10 0x000ff000
};
const byte kInstruction_rsc_vc_r4_r12_0x00000000[] = {
  0x00, 0x40, 0xec, 0x72 // rsc vc r4 r12 0x00000000
};
const byte kInstruction_rsc_pl_r7_r7_0x02ac0000[] = {
  0xab, 0x77, 0xe7, 0x52 // rsc pl r7 r7 0x02ac0000
};
const byte kInstruction_rsc_ge_r6_r11_0x02ac0000[] = {
  0xab, 0x67, 0xeb, 0xa2 // rsc ge r6 r11 0x02ac0000
};
const byte kInstruction_rsc_ls_r10_r4_0x000000ff[] = {
  0xff, 0xa0, 0xe4, 0x92 // rsc ls r10 r4 0x000000ff
};
const byte kInstruction_rsc_cc_r12_r4_0x00000ff0[] = {
  0xff, 0xce, 0xe4, 0x32 // rsc cc r12 r4 0x00000ff0
};
const byte kInstruction_rsc_gt_r6_r3_0x0ff00000[] = {
  0xff, 0x66, 0xe3, 0xc2 // rsc gt r6 r3 0x0ff00000
};
const byte kInstruction_rsc_cc_r3_r10_0x00ab0000[] = {
  0xab, 0x38, 0xea, 0x32 // rsc cc r3 r10 0x00ab0000
};
const byte kInstruction_rsc_eq_r6_r7_0x00ab0000[] = {
  0xab, 0x68, 0xe7, 0x02 // rsc eq r6 r7 0x00ab0000
};
const byte kInstruction_rsc_le_r3_r3_0x003fc000[] = {
  0xff, 0x39, 0xe3, 0xd2 // rsc le r3 r3 0x003fc000
};
const byte kInstruction_rsc_lt_r11_r3_0x3fc00000[] = {
  0xff, 0xb5, 0xe3, 0xb2 // rsc lt r11 r3 0x3fc00000
};
const byte kInstruction_rsc_vc_r11_r2_0x00003fc0[] = {
  0xff, 0xbd, 0xe2, 0x72 // rsc vc r11 r2 0x00003fc0
};
const byte kInstruction_rsc_ls_r11_r11_0x000ff000[] = {
  0xff, 0xba, 0xeb, 0x92 // rsc ls r11 r11 0x000ff000
};
const byte kInstruction_rsc_eq_r13_r2_0x0000ff00[] = {
  0xff, 0xdc, 0xe2, 0x02 // rsc eq r13 r2 0x0000ff00
};
const byte kInstruction_rsc_vc_r9_r1_0x00002ac0[] = {
  0xab, 0x9d, 0xe1, 0x72 // rsc vc r9 r1 0x00002ac0
};
const byte kInstruction_rsc_ne_r2_r14_0xfc000003[] = {
  0xff, 0x23, 0xee, 0x12 // rsc ne r2 r14 0xfc000003
};
const byte kInstruction_rsc_vs_r10_r11_0x00002ac0[] = {
  0xab, 0xad, 0xeb, 0x62 // rsc vs r10 r11 0x00002ac0
};
const byte kInstruction_rsc_cc_r9_r9_0x000002ac[] = {
  0xab, 0x9f, 0xe9, 0x32 // rsc cc r9 r9 0x000002ac
};
const byte kInstruction_rsc_gt_r9_r3_0x0000ab00[] = {
  0xab, 0x9c, 0xe3, 0xc2 // rsc gt r9 r3 0x0000ab00
};
const byte kInstruction_rsc_ge_r3_r0_0x000000ab[] = {
  0xab, 0x30, 0xe0, 0xa2 // rsc ge r3 r0 0x000000ab
};
const byte kInstruction_rsc_pl_r6_r11_0xb000000a[] = {
  0xab, 0x62, 0xeb, 0x52 // rsc pl r6 r11 0xb000000a
};
const byte kInstruction_rsc_cs_r7_r3_0xb000000a[] = {
  0xab, 0x72, 0xe3, 0x22 // rsc cs r7 r3 0xb000000a
};
const byte kInstruction_rsc_ge_r0_r8_0x00ff0000[] = {
  0xff, 0x08, 0xe8, 0xa2 // rsc ge r0 r8 0x00ff0000
};
const byte kInstruction_rsc_lt_r9_r0_0x00ab0000[] = {
  0xab, 0x98, 0xe0, 0xb2 // rsc lt r9 r0 0x00ab0000
};
const byte kInstruction_rsc_cs_r8_r0_0xc000003f[] = {
  0xff, 0x81, 0xe0, 0x22 // rsc cs r8 r0 0xc000003f
};
const byte kInstruction_rsc_eq_r2_r5_0x03fc0000[] = {
  0xff, 0x27, 0xe5, 0x02 // rsc eq r2 r5 0x03fc0000
};
const byte kInstruction_rsc_ls_r1_r9_0x0000ab00[] = {
  0xab, 0x1c, 0xe9, 0x92 // rsc ls r1 r9 0x0000ab00
};
const byte kInstruction_rsc_al_r3_r1_0x00000ab0[] = {
  0xab, 0x3e, 0xe1, 0xe2 // rsc al r3 r1 0x00000ab0
};
const byte kInstruction_rsc_gt_r11_r11_0xfc000003[] = {
  0xff, 0xb3, 0xeb, 0xc2 // rsc gt r11 r11 0xfc000003
};
const byte kInstruction_rsc_hi_r9_r8_0x00000ab0[] = {
  0xab, 0x9e, 0xe8, 0x82 // rsc hi r9 r8 0x00000ab0
};
const byte kInstruction_rsc_gt_r6_r10_0xff000000[] = {
  0xff, 0x64, 0xea, 0xc2 // rsc gt r6 r10 0xff000000
};
const byte kInstruction_rsc_le_r9_r14_0x00003fc0[] = {
  0xff, 0x9d, 0xee, 0xd2 // rsc le r9 r14 0x00003fc0
};
const byte kInstruction_rsc_cc_r11_r0_0xf000000f[] = {
  0xff, 0xb2, 0xe0, 0x32 // rsc cc r11 r0 0xf000000f
};
const byte kInstruction_rsc_pl_r8_r5_0x000002ac[] = {
  0xab, 0x8f, 0xe5, 0x52 // rsc pl r8 r5 0x000002ac
};
const byte kInstruction_rsc_gt_r1_r15_0x000ff000[] = {
  0xff, 0x1a, 0xef, 0xc2 // rsc gt r1 r15 0x000ff000
};
const byte kInstruction_rsc_eq_r1_r2_0x02ac0000[] = {
  0xab, 0x17, 0xe2, 0x02 // rsc eq r1 r2 0x02ac0000
};
const byte kInstruction_rsc_ge_r8_r7_0x0ff00000[] = {
  0xff, 0x86, 0xe7, 0xa2 // rsc ge r8 r7 0x0ff00000
};
const byte kInstruction_rsc_le_r15_r14_0x0000ab00[] = {
  0xab, 0xfc, 0xee, 0xd2 // rsc le r15 r14 0x0000ab00
};
const byte kInstruction_rsc_al_r15_r11_0x00002ac0[] = {
  0xab, 0xfd, 0xeb, 0xe2 // rsc al r15 r11 0x00002ac0
};
const byte kInstruction_rsc_al_r11_r4_0x000002ac[] = {
  0xab, 0xbf, 0xe4, 0xe2 // rsc al r11 r4 0x000002ac
};
const byte kInstruction_rsc_le_r13_r12_0x000003fc[] = {
  0xff, 0xdf, 0xec, 0xd2 // rsc le r13 r12 0x000003fc
};
const byte kInstruction_rsc_al_r15_r8_0x000ff000[] = {
  0xff, 0xfa, 0xe8, 0xe2 // rsc al r15 r8 0x000ff000
};
const byte kInstruction_rsc_eq_r4_r2_0x0002ac00[] = {
  0xab, 0x4b, 0xe2, 0x02 // rsc eq r4 r2 0x0002ac00
};
const byte kInstruction_rsc_ge_r1_r9_0x002ac000[] = {
  0xab, 0x19, 0xe9, 0xa2 // rsc ge r1 r9 0x002ac000
};
const byte kInstruction_rsc_lt_r12_r5_0x00000000[] = {
  0x00, 0xc0, 0xe5, 0xb2 // rsc lt r12 r5 0x00000000
};
const byte kInstruction_rsc_pl_r10_r8_0x00000ff0[] = {
  0xff, 0xae, 0xe8, 0x52 // rsc pl r10 r8 0x00000ff0
};
const byte kInstruction_rsc_ge_r13_r12_0x00ff0000[] = {
  0xff, 0xd8, 0xec, 0xa2 // rsc ge r13 r12 0x00ff0000
};
const byte kInstruction_rsc_al_r9_r7_0x00000ff0[] = {
  0xff, 0x9e, 0xe7, 0xe2 // rsc al r9 r7 0x00000ff0
};
const byte kInstruction_rsc_ls_r6_r3_0x00000000[] = {
  0x00, 0x60, 0xe3, 0x92 // rsc ls r6 r3 0x00000000
};
const byte kInstruction_rsc_al_r1_r2_0x00002ac0[] = {
  0xab, 0x1d, 0xe2, 0xe2 // rsc al r1 r2 0x00002ac0
};
const byte kInstruction_rsc_le_r4_r12_0x0002ac00[] = {
  0xab, 0x4b, 0xec, 0xd2 // rsc le r4 r12 0x0002ac00
};
const byte kInstruction_rsc_ge_r7_r1_0x0000ff00[] = {
  0xff, 0x7c, 0xe1, 0xa2 // rsc ge r7 r1 0x0000ff00
};
const byte kInstruction_rsc_le_r10_r14_0x3fc00000[] = {
  0xff, 0xa5, 0xee, 0xd2 // rsc le r10 r14 0x3fc00000
};
const byte kInstruction_rsc_al_r7_r9_0x000000ab[] = {
  0xab, 0x70, 0xe9, 0xe2 // rsc al r7 r9 0x000000ab
};
const byte kInstruction_rsc_hi_r6_r3_0x000003fc[] = {
  0xff, 0x6f, 0xe3, 0x82 // rsc hi r6 r3 0x000003fc
};
const byte kInstruction_rsc_cs_r14_r11_0x000000ff[] = {
  0xff, 0xe0, 0xeb, 0x22 // rsc cs r14 r11 0x000000ff
};
const byte kInstruction_rsc_le_r0_r15_0xab000000[] = {
  0xab, 0x04, 0xef, 0xd2 // rsc le r0 r15 0xab000000
};
const byte kInstruction_rsc_ls_r0_r3_0xc000002a[] = {
  0xab, 0x01, 0xe3, 0x92 // rsc ls r0 r3 0xc000002a
};
const byte kInstruction_rsc_le_r5_r6_0x000002ac[] = {
  0xab, 0x5f, 0xe6, 0xd2 // rsc le r5 r6 0x000002ac
};
const byte kInstruction_rsc_eq_r5_r9_0xb000000a[] = {
  0xab, 0x52, 0xe9, 0x02 // rsc eq r5 r9 0xb000000a
};
const byte kInstruction_rsc_al_r12_r6_0x000002ac[] = {
  0xab, 0xcf, 0xe6, 0xe2 // rsc al r12 r6 0x000002ac
};
const byte kInstruction_rsc_vs_r11_r10_0x0003fc00[] = {
  0xff, 0xbb, 0xea, 0x62 // rsc vs r11 r10 0x0003fc00
};
const byte kInstruction_rsc_gt_r8_r5_0x0003fc00[] = {
  0xff, 0x8b, 0xe5, 0xc2 // rsc gt r8 r5 0x0003fc00
};
const byte kInstruction_rsc_eq_r1_r9_0x00000000[] = {
  0x00, 0x10, 0xe9, 0x02 // rsc eq r1 r9 0x00000000
};
const byte kInstruction_rsc_ge_r2_r9_0x3fc00000[] = {
  0xff, 0x25, 0xe9, 0xa2 // rsc ge r2 r9 0x3fc00000
};
const byte kInstruction_rsc_cs_r4_r13_0x00ab0000[] = {
  0xab, 0x48, 0xed, 0x22 // rsc cs r4 r13 0x00ab0000
};
const byte kInstruction_rsc_hi_r4_r12_0x00ab0000[] = {
  0xab, 0x48, 0xec, 0x82 // rsc hi r4 r12 0x00ab0000
};
const byte kInstruction_rsc_ne_r2_r3_0x003fc000[] = {
  0xff, 0x29, 0xe3, 0x12 // rsc ne r2 r3 0x003fc000
};
const byte kInstruction_rsc_vs_r0_r11_0xfc000003[] = {
  0xff, 0x03, 0xeb, 0x62 // rsc vs r0 r11 0xfc000003
};
const byte kInstruction_rsc_hi_r14_r9_0x003fc000[] = {
  0xff, 0xe9, 0xe9, 0x82 // rsc hi r14 r9 0x003fc000
};
const byte kInstruction_rsc_vc_r7_r5_0xab000000[] = {
  0xab, 0x74, 0xe5, 0x72 // rsc vc r7 r5 0xab000000
};
const byte kInstruction_rsc_lt_r15_r8_0x002ac000[] = {
  0xab, 0xf9, 0xe8, 0xb2 // rsc lt r15 r8 0x002ac000
};
const byte kInstruction_rsc_cs_r3_r7_0x0003fc00[] = {
  0xff, 0x3b, 0xe7, 0x22 // rsc cs r3 r7 0x0003fc00
};
const byte kInstruction_rsc_cs_r7_r11_0xb000000a[] = {
  0xab, 0x72, 0xeb, 0x22 // rsc cs r7 r11 0xb000000a
};
const byte kInstruction_rsc_ge_r0_r11_0xb000000a[] = {
  0xab, 0x02, 0xeb, 0xa2 // rsc ge r0 r11 0xb000000a
};
const byte kInstruction_rsc_vs_r6_r5_0x0ab00000[] = {
  0xab, 0x66, 0xe5, 0x62 // rsc vs r6 r5 0x0ab00000
};
const byte kInstruction_rsc_le_r10_r1_0xfc000003[] = {
  0xff, 0xa3, 0xe1, 0xd2 // rsc le r10 r1 0xfc000003
};
const byte kInstruction_rsc_cc_r3_r6_0x3fc00000[] = {
  0xff, 0x35, 0xe6, 0x32 // rsc cc r3 r6 0x3fc00000
};
const byte kInstruction_rsc_le_r12_r14_0x00000ab0[] = {
  0xab, 0xce, 0xee, 0xd2 // rsc le r12 r14 0x00000ab0
};
const byte kInstruction_rsc_al_r15_r12_0x00003fc0[] = {
  0xff, 0xfd, 0xec, 0xe2 // rsc al r15 r12 0x00003fc0
};
const byte kInstruction_rsc_gt_r12_r10_0x0000ab00[] = {
  0xab, 0xcc, 0xea, 0xc2 // rsc gt r12 r10 0x0000ab00
};
const byte kInstruction_rsc_ls_r6_r15_0x0ff00000[] = {
  0xff, 0x66, 0xef, 0x92 // rsc ls r6 r15 0x0ff00000
};
const byte kInstruction_rsc_mi_r4_r4_0x00003fc0[] = {
  0xff, 0x4d, 0xe4, 0x42 // rsc mi r4 r4 0x00003fc0
};
const byte kInstruction_rsc_gt_r8_r9_0xc000002a[] = {
  0xab, 0x81, 0xe9, 0xc2 // rsc gt r8 r9 0xc000002a
};
const byte kInstruction_rsc_le_r10_r4_0x000002ac[] = {
  0xab, 0xaf, 0xe4, 0xd2 // rsc le r10 r4 0x000002ac
};
const byte kInstruction_rsc_vs_r0_r1_0x000003fc[] = {
  0xff, 0x0f, 0xe1, 0x62 // rsc vs r0 r1 0x000003fc
};
const byte kInstruction_rsc_al_r1_r5_0x0ff00000[] = {
  0xff, 0x16, 0xe5, 0xe2 // rsc al r1 r5 0x0ff00000
};
const byte kInstruction_rsc_cc_r11_r5_0xc000002a[] = {
  0xab, 0xb1, 0xe5, 0x32 // rsc cc r11 r5 0xc000002a
};
const byte kInstruction_rsc_vc_r6_r13_0x003fc000[] = {
  0xff, 0x69, 0xed, 0x72 // rsc vc r6 r13 0x003fc000
};
const byte kInstruction_rsc_eq_r1_r15_0x00003fc0[] = {
  0xff, 0x1d, 0xef, 0x02 // rsc eq r1 r15 0x00003fc0
};
const byte kInstruction_rsc_lt_r15_r10_0x000002ac[] = {
  0xab, 0xff, 0xea, 0xb2 // rsc lt r15 r10 0x000002ac
};
const byte kInstruction_rsc_ne_r13_r13_0x003fc000[] = {
  0xff, 0xd9, 0xed, 0x12 // rsc ne r13 r13 0x003fc000
};
const byte kInstruction_rsc_mi_r11_r7_0xc000002a[] = {
  0xab, 0xb1, 0xe7, 0x42 // rsc mi r11 r7 0xc000002a
};
const byte kInstruction_rsc_cc_r6_r2_0x00ff0000[] = {
  0xff, 0x68, 0xe2, 0x32 // rsc cc r6 r2 0x00ff0000
};
const byte kInstruction_rsc_gt_r9_r1_0x0000ab00[] = {
  0xab, 0x9c, 0xe1, 0xc2 // rsc gt r9 r1 0x0000ab00
};
const byte kInstruction_rsc_le_r11_r7_0x000000ff[] = {
  0xff, 0xb0, 0xe7, 0xd2 // rsc le r11 r7 0x000000ff
};
const byte kInstruction_rsc_hi_r9_r8_0x0002ac00[] = {
  0xab, 0x9b, 0xe8, 0x82 // rsc hi r9 r8 0x0002ac00
};
const byte kInstruction_rsc_vs_r6_r8_0xff000000[] = {
  0xff, 0x64, 0xe8, 0x62 // rsc vs r6 r8 0xff000000
};
const byte kInstruction_rsc_mi_r10_r4_0x000ab000[] = {
  0xab, 0xaa, 0xe4, 0x42 // rsc mi r10 r4 0x000ab000
};
const byte kInstruction_rsc_ls_r7_r10_0xab000000[] = {
  0xab, 0x74, 0xea, 0x92 // rsc ls r7 r10 0xab000000
};
const byte kInstruction_rsc_lt_r1_r0_0x00000000[] = {
  0x00, 0x10, 0xe0, 0xb2 // rsc lt r1 r0 0x00000000
};
const byte kInstruction_rsc_eq_r2_r13_0x00002ac0[] = {
  0xab, 0x2d, 0xed, 0x02 // rsc eq r2 r13 0x00002ac0
};
const byte kInstruction_rsc_cc_r14_r13_0x00003fc0[] = {
  0xff, 0xed, 0xed, 0x32 // rsc cc r14 r13 0x00003fc0
};
const byte kInstruction_rsc_le_r9_r4_0x0ab00000[] = {
  0xab, 0x96, 0xe4, 0xd2 // rsc le r9 r4 0x0ab00000
};
const byte kInstruction_rsc_gt_r4_r7_0x00000ab0[] = {
  0xab, 0x4e, 0xe7, 0xc2 // rsc gt r4 r7 0x00000ab0
};
const byte kInstruction_rsc_eq_r5_r4_0xc000003f[] = {
  0xff, 0x51, 0xe4, 0x02 // rsc eq r5 r4 0xc000003f
};
const byte kInstruction_rsc_al_r2_r13_0xb000000a[] = {
  0xab, 0x22, 0xed, 0xe2 // rsc al r2 r13 0xb000000a
};
const byte kInstruction_rsc_le_r13_r11_0x2ac00000[] = {
  0xab, 0xd5, 0xeb, 0xd2 // rsc le r13 r11 0x2ac00000
};
const byte kInstruction_rsc_gt_r5_r14_0xac000002[] = {
  0xab, 0x53, 0xee, 0xc2 // rsc gt r5 r14 0xac000002
};
const byte kInstruction_rsc_vs_r2_r7_0x000000ab[] = {
  0xab, 0x20, 0xe7, 0x62 // rsc vs r2 r7 0x000000ab
};
const byte kInstruction_rsc_ne_r6_r1_0x0ab00000[] = {
  0xab, 0x66, 0xe1, 0x12 // rsc ne r6 r1 0x0ab00000
};
const byte kInstruction_rsc_eq_r4_r7_0x0000ff00[] = {
  0xff, 0x4c, 0xe7, 0x02 // rsc eq r4 r7 0x0000ff00
};
const byte kInstruction_rsc_cc_r11_r12_0xc000003f[] = {
  0xff, 0xb1, 0xec, 0x32 // rsc cc r11 r12 0xc000003f
};
const byte kInstruction_rsc_pl_r7_r9_0x02ac0000[] = {
  0xab, 0x77, 0xe9, 0x52 // rsc pl r7 r9 0x02ac0000
};
const byte kInstruction_rsc_vc_r5_r4_0x00000000[] = {
  0x00, 0x50, 0xe4, 0x72 // rsc vc r5 r4 0x00000000
};
const byte kInstruction_rsc_le_r7_r1_0xc000002a[] = {
  0xab, 0x71, 0xe1, 0xd2 // rsc le r7 r1 0xc000002a
};
const byte kInstruction_rsc_cs_r3_r10_0x2ac00000[] = {
  0xab, 0x35, 0xea, 0x22 // rsc cs r3 r10 0x2ac00000
};
const byte kInstruction_rsc_le_r11_r13_0x00003fc0[] = {
  0xff, 0xbd, 0xed, 0xd2 // rsc le r11 r13 0x00003fc0
};
const byte kInstruction_rsc_pl_r2_r11_0x000000ff[] = {
  0xff, 0x20, 0xeb, 0x52 // rsc pl r2 r11 0x000000ff
};
const byte kInstruction_rsc_cs_r14_r11_0x00000000[] = {
  0x00, 0xe0, 0xeb, 0x22 // rsc cs r14 r11 0x00000000
};
const byte kInstruction_rsc_ls_r6_r8_0x003fc000[] = {
  0xff, 0x69, 0xe8, 0x92 // rsc ls r6 r8 0x003fc000
};
const byte kInstruction_rsc_al_r6_r8_0xab000000[] = {
  0xab, 0x64, 0xe8, 0xe2 // rsc al r6 r8 0xab000000
};
const byte kInstruction_rsc_cc_r4_r2_0x002ac000[] = {
  0xab, 0x49, 0xe2, 0x32 // rsc cc r4 r2 0x002ac000
};
const byte kInstruction_rsc_lt_r3_r13_0x003fc000[] = {
  0xff, 0x39, 0xed, 0xb2 // rsc lt r3 r13 0x003fc000
};
const byte kInstruction_rsc_lt_r7_r3_0x02ac0000[] = {
  0xab, 0x77, 0xe3, 0xb2 // rsc lt r7 r3 0x02ac0000
};
const byte kInstruction_rsc_gt_r12_r1_0x0000ff00[] = {
  0xff, 0xcc, 0xe1, 0xc2 // rsc gt r12 r1 0x0000ff00
};
const byte kInstruction_rsc_mi_r13_r11_0x02ac0000[] = {
  0xab, 0xd7, 0xeb, 0x42 // rsc mi r13 r11 0x02ac0000
};
const byte kInstruction_rsc_al_r9_r0_0xc000003f[] = {
  0xff, 0x91, 0xe0, 0xe2 // rsc al r9 r0 0xc000003f
};
const byte kInstruction_rsc_mi_r12_r9_0x00003fc0[] = {
  0xff, 0xcd, 0xe9, 0x42 // rsc mi r12 r9 0x00003fc0
};
const byte kInstruction_rsc_ge_r5_r2_0x3fc00000[] = {
  0xff, 0x55, 0xe2, 0xa2 // rsc ge r5 r2 0x3fc00000
};
const byte kInstruction_rsc_gt_r4_r2_0x002ac000[] = {
  0xab, 0x49, 0xe2, 0xc2 // rsc gt r4 r2 0x002ac000
};
const byte kInstruction_rsc_cs_r6_r13_0x00003fc0[] = {
  0xff, 0x6d, 0xed, 0x22 // rsc cs r6 r13 0x00003fc0
};
const byte kInstruction_rsc_ne_r14_r0_0xff000000[] = {
  0xff, 0xe4, 0xe0, 0x12 // rsc ne r14 r0 0xff000000
};
const byte kInstruction_rsc_ls_r5_r11_0xc000002a[] = {
  0xab, 0x51, 0xeb, 0x92 // rsc ls r5 r11 0xc000002a
};
const byte kInstruction_rsc_gt_r11_r6_0xf000000f[] = {
  0xff, 0xb2, 0xe6, 0xc2 // rsc gt r11 r6 0xf000000f
};
const byte kInstruction_rsc_ne_r11_r5_0x000000ff[] = {
  0xff, 0xb0, 0xe5, 0x12 // rsc ne r11 r5 0x000000ff
};
const byte kInstruction_rsc_eq_r9_r14_0x0ab00000[] = {
  0xab, 0x96, 0xee, 0x02 // rsc eq r9 r14 0x0ab00000
};
const byte kInstruction_rsc_cs_r0_r10_0x0002ac00[] = {
  0xab, 0x0b, 0xea, 0x22 // rsc cs r0 r10 0x0002ac00
};
const byte kInstruction_rsc_ls_r15_r15_0x00003fc0[] = {
  0xff, 0xfd, 0xef, 0x92 // rsc ls r15 r15 0x00003fc0
};
const byte kInstruction_rsc_eq_r2_r2_0xc000003f[] = {
  0xff, 0x21, 0xe2, 0x02 // rsc eq r2 r2 0xc000003f
};
const byte kInstruction_rsc_ls_r10_r3_0xfc000003[] = {
  0xff, 0xa3, 0xe3, 0x92 // rsc ls r10 r3 0xfc000003
};
const byte kInstruction_rsc_gt_r9_r2_0x000ab000[] = {
  0xab, 0x9a, 0xe2, 0xc2 // rsc gt r9 r2 0x000ab000
};
const byte kInstruction_rsc_vc_r7_r6_0xb000000a[] = {
  0xab, 0x72, 0xe6, 0x72 // rsc vc r7 r6 0xb000000a
};
const byte kInstruction_rsc_vs_r9_r0_0x002ac000[] = {
  0xab, 0x99, 0xe0, 0x62 // rsc vs r9 r0 0x002ac000
};
const byte kInstruction_rsc_hi_r10_r8_0x2ac00000[] = {
  0xab, 0xa5, 0xe8, 0x82 // rsc hi r10 r8 0x2ac00000
};
const byte kInstruction_rsc_vs_r15_r6_0x003fc000[] = {
  0xff, 0xf9, 0xe6, 0x62 // rsc vs r15 r6 0x003fc000
};
const byte kInstruction_rsc_cc_r1_r8_0x2ac00000[] = {
  0xab, 0x15, 0xe8, 0x32 // rsc cc r1 r8 0x2ac00000
};
const byte kInstruction_rsc_gt_r5_r14_0x000ab000[] = {
  0xab, 0x5a, 0xee, 0xc2 // rsc gt r5 r14 0x000ab000
};
const byte kInstruction_rsc_ls_r2_r9_0xc000003f[] = {
  0xff, 0x21, 0xe9, 0x92 // rsc ls r2 r9 0xc000003f
};
const byte kInstruction_rsc_vs_r1_r10_0x00000000[] = {
  0x00, 0x10, 0xea, 0x62 // rsc vs r1 r10 0x00000000
};
const byte kInstruction_rsc_lt_r8_r12_0x0ff00000[] = {
  0xff, 0x86, 0xec, 0xb2 // rsc lt r8 r12 0x0ff00000
};
const byte kInstruction_rsc_cc_r13_r14_0x00002ac0[] = {
  0xab, 0xdd, 0xee, 0x32 // rsc cc r13 r14 0x00002ac0
};
const byte kInstruction_rsc_gt_r0_r3_0x00003fc0[] = {
  0xff, 0x0d, 0xe3, 0xc2 // rsc gt r0 r3 0x00003fc0
};
const byte kInstruction_rsc_le_r0_r0_0xc000003f[] = {
  0xff, 0x01, 0xe0, 0xd2 // rsc le r0 r0 0xc000003f
};
const byte kInstruction_rsc_vc_r8_r8_0xff000000[] = {
  0xff, 0x84, 0xe8, 0x72 // rsc vc r8 r8 0xff000000
};
const byte kInstruction_rsc_vc_r0_r5_0x00002ac0[] = {
  0xab, 0x0d, 0xe5, 0x72 // rsc vc r0 r5 0x00002ac0
};
const byte kInstruction_rsc_ls_r3_r10_0x00ff0000[] = {
  0xff, 0x38, 0xea, 0x92 // rsc ls r3 r10 0x00ff0000
};
const byte kInstruction_rsc_cc_r5_r2_0x03fc0000[] = {
  0xff, 0x57, 0xe2, 0x32 // rsc cc r5 r2 0x03fc0000
};
const byte kInstruction_rsc_ls_r13_r8_0xc000002a[] = {
  0xab, 0xd1, 0xe8, 0x92 // rsc ls r13 r8 0xc000002a
};
const byte kInstruction_rsc_vc_r14_r4_0x3fc00000[] = {
  0xff, 0xe5, 0xe4, 0x72 // rsc vc r14 r4 0x3fc00000
};
const byte kInstruction_rsc_eq_r7_r8_0xac000002[] = {
  0xab, 0x73, 0xe8, 0x02 // rsc eq r7 r8 0xac000002
};
const byte kInstruction_rsc_al_r13_r13_0x002ac000[] = {
  0xab, 0xd9, 0xed, 0xe2 // rsc al r13 r13 0x002ac000
};
const byte kInstruction_rsc_vc_r0_r10_0x000ff000[] = {
  0xff, 0x0a, 0xea, 0x72 // rsc vc r0 r10 0x000ff000
};
const byte kInstruction_rsc_vc_r11_r12_0x00002ac0[] = {
  0xab, 0xbd, 0xec, 0x72 // rsc vc r11 r12 0x00002ac0
};
const byte kInstruction_rsc_mi_r15_r4_0x000ff000[] = {
  0xff, 0xfa, 0xe4, 0x42 // rsc mi r15 r4 0x000ff000
};
const byte kInstruction_rsc_eq_r3_r0_0xfc000003[] = {
  0xff, 0x33, 0xe0, 0x02 // rsc eq r3 r0 0xfc000003
};
const byte kInstruction_rsc_mi_r9_r8_0xab000000[] = {
  0xab, 0x94, 0xe8, 0x42 // rsc mi r9 r8 0xab000000
};
const byte kInstruction_rsc_cc_r5_r7_0xc000003f[] = {
  0xff, 0x51, 0xe7, 0x32 // rsc cc r5 r7 0xc000003f
};
const byte kInstruction_rsc_eq_r9_r15_0x002ac000[] = {
  0xab, 0x99, 0xef, 0x02 // rsc eq r9 r15 0x002ac000
};
const byte kInstruction_rsc_ne_r7_r5_0x00000ab0[] = {
  0xab, 0x7e, 0xe5, 0x12 // rsc ne r7 r5 0x00000ab0
};
const byte kInstruction_rsc_eq_r15_r12_0x000002ac[] = {
  0xab, 0xff, 0xec, 0x02 // rsc eq r15 r12 0x000002ac
};
const byte kInstruction_rsc_cs_r0_r13_0x00003fc0[] = {
  0xff, 0x0d, 0xed, 0x22 // rsc cs r0 r13 0x00003fc0
};
const byte kInstruction_rsc_gt_r13_r11_0xac000002[] = {
  0xab, 0xd3, 0xeb, 0xc2 // rsc gt r13 r11 0xac000002
};
const byte kInstruction_rsc_pl_r4_r10_0x2ac00000[] = {
  0xab, 0x45, 0xea, 0x52 // rsc pl r4 r10 0x2ac00000
};
const byte kInstruction_rsc_ne_r3_r13_0xac000002[] = {
  0xab, 0x33, 0xed, 0x12 // rsc ne r3 r13 0xac000002
};
const byte kInstruction_rsc_eq_r8_r7_0x000002ac[] = {
  0xab, 0x8f, 0xe7, 0x02 // rsc eq r8 r7 0x000002ac
};
const byte kInstruction_rsc_vs_r7_r6_0xab000000[] = {
  0xab, 0x74, 0xe6, 0x62 // rsc vs r7 r6 0xab000000
};
const byte kInstruction_rsc_le_r14_r3_0x00003fc0[] = {
  0xff, 0xed, 0xe3, 0xd2 // rsc le r14 r3 0x00003fc0
};
const byte kInstruction_rsc_mi_r3_r5_0x0ab00000[] = {
  0xab, 0x36, 0xe5, 0x42 // rsc mi r3 r5 0x0ab00000
};
const byte kInstruction_rsc_lt_r9_r1_0x000000ff[] = {
  0xff, 0x90, 0xe1, 0xb2 // rsc lt r9 r1 0x000000ff
};
const byte kInstruction_rsc_vc_r6_r2_0xff000000[] = {
  0xff, 0x64, 0xe2, 0x72 // rsc vc r6 r2 0xff000000
};
const byte kInstruction_rsc_mi_r8_r3_0xfc000003[] = {
  0xff, 0x83, 0xe3, 0x42 // rsc mi r8 r3 0xfc000003
};
const byte kInstruction_rsc_gt_r14_r11_0x000000ab[] = {
  0xab, 0xe0, 0xeb, 0xc2 // rsc gt r14 r11 0x000000ab
};
const byte kInstruction_rsc_eq_r8_r14_0x0000ff00[] = {
  0xff, 0x8c, 0xee, 0x02 // rsc eq r8 r14 0x0000ff00
};
const byte kInstruction_rsc_vs_r0_r5_0x000002ac[] = {
  0xab, 0x0f, 0xe5, 0x62 // rsc vs r0 r5 0x000002ac
};
const byte kInstruction_rsc_cs_r15_r15_0x00000ff0[] = {
  0xff, 0xfe, 0xef, 0x22 // rsc cs r15 r15 0x00000ff0
};
const byte kInstruction_rsc_le_r3_r0_0x000000ff[] = {
  0xff, 0x30, 0xe0, 0xd2 // rsc le r3 r0 0x000000ff
};
const byte kInstruction_rsc_vc_r3_r12_0x000002ac[] = {
  0xab, 0x3f, 0xec, 0x72 // rsc vc r3 r12 0x000002ac
};
const byte kInstruction_rsc_ne_r15_r9_0x03fc0000[] = {
  0xff, 0xf7, 0xe9, 0x12 // rsc ne r15 r9 0x03fc0000
};
const byte kInstruction_rsc_ls_r8_r14_0x000002ac[] = {
  0xab, 0x8f, 0xee, 0x92 // rsc ls r8 r14 0x000002ac
};
const byte kInstruction_rsc_eq_r7_r10_0x03fc0000[] = {
  0xff, 0x77, 0xea, 0x02 // rsc eq r7 r10 0x03fc0000
};
const byte kInstruction_rsc_vc_r0_r7_0xab000000[] = {
  0xab, 0x04, 0xe7, 0x72 // rsc vc r0 r7 0xab000000
};
const byte kInstruction_rsc_vc_r3_r11_0xff000000[] = {
  0xff, 0x34, 0xeb, 0x72 // rsc vc r3 r11 0xff000000
};
const byte kInstruction_rsc_cs_r14_r2_0xfc000003[] = {
  0xff, 0xe3, 0xe2, 0x22 // rsc cs r14 r2 0xfc000003
};
const byte kInstruction_rsc_pl_r3_r11_0x00ff0000[] = {
  0xff, 0x38, 0xeb, 0x52 // rsc pl r3 r11 0x00ff0000
};
const byte kInstruction_rsc_lt_r6_r1_0x0002ac00[] = {
  0xab, 0x6b, 0xe1, 0xb2 // rsc lt r6 r1 0x0002ac00
};
const byte kInstruction_rsc_al_r15_r1_0xf000000f[] = {
  0xff, 0xf2, 0xe1, 0xe2 // rsc al r15 r1 0xf000000f
};
const byte kInstruction_rsc_mi_r12_r7_0x002ac000[] = {
  0xab, 0xc9, 0xe7, 0x42 // rsc mi r12 r7 0x002ac000
};
const byte kInstruction_rsc_vs_r9_r3_0x000003fc[] = {
  0xff, 0x9f, 0xe3, 0x62 // rsc vs r9 r3 0x000003fc
};
const byte kInstruction_rsc_cc_r9_r14_0x000000ff[] = {
  0xff, 0x90, 0xee, 0x32 // rsc cc r9 r14 0x000000ff
};
const byte kInstruction_rsc_ls_r9_r12_0xac000002[] = {
  0xab, 0x93, 0xec, 0x92 // rsc ls r9 r12 0xac000002
};
const byte kInstruction_rsc_al_r13_r13_0xfc000003[] = {
  0xff, 0xd3, 0xed, 0xe2 // rsc al r13 r13 0xfc000003
};
const byte kInstruction_rsc_lt_r14_r1_0x02ac0000[] = {
  0xab, 0xe7, 0xe1, 0xb2 // rsc lt r14 r1 0x02ac0000
};
const byte kInstruction_rsc_le_r8_r15_0x2ac00000[] = {
  0xab, 0x85, 0xef, 0xd2 // rsc le r8 r15 0x2ac00000
};
const byte kInstruction_rsc_al_r10_r8_0x0ab00000[] = {
  0xab, 0xa6, 0xe8, 0xe2 // rsc al r10 r8 0x0ab00000
};
const byte kInstruction_rsc_eq_r3_r6_0x0000ab00[] = {
  0xab, 0x3c, 0xe6, 0x02 // rsc eq r3 r6 0x0000ab00
};
const byte kInstruction_rsc_cs_r6_r9_0xab000000[] = {
  0xab, 0x64, 0xe9, 0x22 // rsc cs r6 r9 0xab000000
};
const byte kInstruction_rsc_al_r13_r1_0xfc000003[] = {
  0xff, 0xd3, 0xe1, 0xe2 // rsc al r13 r1 0xfc000003
};
const byte kInstruction_rsc_ls_r4_r15_0x000002ac[] = {
  0xab, 0x4f, 0xef, 0x92 // rsc ls r4 r15 0x000002ac
};
const byte kInstruction_rsc_cs_r4_r10_0x003fc000[] = {
  0xff, 0x49, 0xea, 0x22 // rsc cs r4 r10 0x003fc000
};
const byte kInstruction_rsc_eq_r2_r8_0x000ab000[] = {
  0xab, 0x2a, 0xe8, 0x02 // rsc eq r2 r8 0x000ab000
};
const byte kInstruction_rsc_eq_r12_r2_0x0003fc00[] = {
  0xff, 0xcb, 0xe2, 0x02 // rsc eq r12 r2 0x0003fc00
};
const byte kInstruction_rsc_vs_r12_r10_0x003fc000[] = {
  0xff, 0xc9, 0xea, 0x62 // rsc vs r12 r10 0x003fc000
};
const byte kInstruction_rsc_eq_r9_r2_0xab000000[] = {
  0xab, 0x94, 0xe2, 0x02 // rsc eq r9 r2 0xab000000
};
const byte kInstruction_rsc_cc_r6_r7_0x0003fc00[] = {
  0xff, 0x6b, 0xe7, 0x32 // rsc cc r6 r7 0x0003fc00
};
const byte kInstruction_rsc_mi_r8_r15_0x0000ff00[] = {
  0xff, 0x8c, 0xef, 0x42 // rsc mi r8 r15 0x0000ff00
};
const byte kInstruction_rsc_ls_r2_r1_0x0ff00000[] = {
  0xff, 0x26, 0xe1, 0x92 // rsc ls r2 r1 0x0ff00000
};
const byte kInstruction_rsc_cs_r12_r12_0x00002ac0[] = {
  0xab, 0xcd, 0xec, 0x22 // rsc cs r12 r12 0x00002ac0
};
const byte kInstruction_rsc_hi_r1_r12_0x000003fc[] = {
  0xff, 0x1f, 0xec, 0x82 // rsc hi r1 r12 0x000003fc
};
const byte kInstruction_rsc_ls_r9_r0_0x000003fc[] = {
  0xff, 0x9f, 0xe0, 0x92 // rsc ls r9 r0 0x000003fc
};
const byte kInstruction_rsc_ne_r6_r9_0x00ff0000[] = {
  0xff, 0x68, 0xe9, 0x12 // rsc ne r6 r9 0x00ff0000
};
const byte kInstruction_rsc_al_r10_r5_0x000000ff[] = {
  0xff, 0xa0, 0xe5, 0xe2 // rsc al r10 r5 0x000000ff
};
const byte kInstruction_rsc_pl_r10_r4_0xf000000f[] = {
  0xff, 0xa2, 0xe4, 0x52 // rsc pl r10 r4 0xf000000f
};
const byte kInstruction_rsc_hi_r0_r11_0x03fc0000[] = {
  0xff, 0x07, 0xeb, 0x82 // rsc hi r0 r11 0x03fc0000
};
const byte kInstruction_rsc_al_r6_r3_0x00002ac0[] = {
  0xab, 0x6d, 0xe3, 0xe2 // rsc al r6 r3 0x00002ac0
};
const byte kInstruction_rsc_ne_r12_r13_0x0000ab00[] = {
  0xab, 0xcc, 0xed, 0x12 // rsc ne r12 r13 0x0000ab00
};
const byte kInstruction_rsc_mi_r13_r8_0x00002ac0[] = {
  0xab, 0xdd, 0xe8, 0x42 // rsc mi r13 r8 0x00002ac0
};
const byte kInstruction_rsc_ge_r13_r2_0x003fc000[] = {
  0xff, 0xd9, 0xe2, 0xa2 // rsc ge r13 r2 0x003fc000
};
const byte kInstruction_rsc_pl_r10_r15_0x00ff0000[] = {
  0xff, 0xa8, 0xef, 0x52 // rsc pl r10 r15 0x00ff0000
};
const byte kInstruction_rsc_vs_r12_r7_0xff000000[] = {
  0xff, 0xc4, 0xe7, 0x62 // rsc vs r12 r7 0xff000000
};
const byte kInstruction_rsc_cs_r1_r3_0xfc000003[] = {
  0xff, 0x13, 0xe3, 0x22 // rsc cs r1 r3 0xfc000003
};
const byte kInstruction_rsc_ne_r9_r4_0x000002ac[] = {
  0xab, 0x9f, 0xe4, 0x12 // rsc ne r9 r4 0x000002ac
};
const byte kInstruction_rsc_vs_r14_r3_0x02ac0000[] = {
  0xab, 0xe7, 0xe3, 0x62 // rsc vs r14 r3 0x02ac0000
};
const byte kInstruction_rsc_vs_r0_r2_0x0ff00000[] = {
  0xff, 0x06, 0xe2, 0x62 // rsc vs r0 r2 0x0ff00000
};
const byte kInstruction_rsc_ne_r15_r5_0x000000ab[] = {
  0xab, 0xf0, 0xe5, 0x12 // rsc ne r15 r5 0x000000ab
};
const byte kInstruction_rsc_vs_r9_r13_0x000000ab[] = {
  0xab, 0x90, 0xed, 0x62 // rsc vs r9 r13 0x000000ab
};
const byte kInstruction_rsc_al_r3_r9_0x0000ff00[] = {
  0xff, 0x3c, 0xe9, 0xe2 // rsc al r3 r9 0x0000ff00
};
const byte kInstruction_rsc_cc_r5_r8_0xac000002[] = {
  0xab, 0x53, 0xe8, 0x32 // rsc cc r5 r8 0xac000002
};
const byte kInstruction_rsc_ne_r0_r13_0x00ab0000[] = {
  0xab, 0x08, 0xed, 0x12 // rsc ne r0 r13 0x00ab0000
};
const byte kInstruction_rsc_vs_r3_r12_0x000ff000[] = {
  0xff, 0x3a, 0xec, 0x62 // rsc vs r3 r12 0x000ff000
};
const byte kInstruction_rsc_gt_r3_r12_0x000003fc[] = {
  0xff, 0x3f, 0xec, 0xc2 // rsc gt r3 r12 0x000003fc
};
const byte kInstruction_rsc_ls_r1_r1_0x002ac000[] = {
  0xab, 0x19, 0xe1, 0x92 // rsc ls r1 r1 0x002ac000
};
const byte kInstruction_rsc_lt_r9_r10_0x2ac00000[] = {
  0xab, 0x95, 0xea, 0xb2 // rsc lt r9 r10 0x2ac00000
};
const byte kInstruction_rsc_hi_r1_r9_0x00003fc0[] = {
  0xff, 0x1d, 0xe9, 0x82 // rsc hi r1 r9 0x00003fc0
};
const byte kInstruction_rsc_ge_r2_r13_0x00002ac0[] = {
  0xab, 0x2d, 0xed, 0xa2 // rsc ge r2 r13 0x00002ac0
};
const byte kInstruction_rsc_ls_r2_r7_0xc000003f[] = {
  0xff, 0x21, 0xe7, 0x92 // rsc ls r2 r7 0xc000003f
};
const byte kInstruction_rsc_eq_r0_r11_0x3fc00000[] = {
  0xff, 0x05, 0xeb, 0x02 // rsc eq r0 r11 0x3fc00000
};
const byte kInstruction_rsc_vc_r13_r7_0x0000ab00[] = {
  0xab, 0xdc, 0xe7, 0x72 // rsc vc r13 r7 0x0000ab00
};
const byte kInstruction_rsc_le_r3_r6_0x00002ac0[] = {
  0xab, 0x3d, 0xe6, 0xd2 // rsc le r3 r6 0x00002ac0
};
const byte kInstruction_rsc_cc_r3_r11_0x0ab00000[] = {
  0xab, 0x36, 0xeb, 0x32 // rsc cc r3 r11 0x0ab00000
};
const byte kInstruction_rsc_ls_r9_r11_0x000002ac[] = {
  0xab, 0x9f, 0xeb, 0x92 // rsc ls r9 r11 0x000002ac
};
const byte kInstruction_rsc_ne_r11_r4_0x00000ff0[] = {
  0xff, 0xbe, 0xe4, 0x12 // rsc ne r11 r4 0x00000ff0
};
const byte kInstruction_rsc_cc_r3_r15_0xfc000003[] = {
  0xff, 0x33, 0xef, 0x32 // rsc cc r3 r15 0xfc000003
};
const byte kInstruction_rsc_ne_r8_r3_0x00003fc0[] = {
  0xff, 0x8d, 0xe3, 0x12 // rsc ne r8 r3 0x00003fc0
};
const byte kInstruction_rsc_vs_r3_r10_0xff000000[] = {
  0xff, 0x34, 0xea, 0x62 // rsc vs r3 r10 0xff000000
};
const byte kInstruction_rsc_mi_r9_r0_0x000002ac[] = {
  0xab, 0x9f, 0xe0, 0x42 // rsc mi r9 r0 0x000002ac
};
const byte kInstruction_rsc_cc_r6_r3_0x0003fc00[] = {
  0xff, 0x6b, 0xe3, 0x32 // rsc cc r6 r3 0x0003fc00
};
const byte kInstruction_rsc_ge_r11_r11_0xac000002[] = {
  0xab, 0xb3, 0xeb, 0xa2 // rsc ge r11 r11 0xac000002
};
const byte kInstruction_rsc_eq_r3_r13_0x003fc000[] = {
  0xff, 0x39, 0xed, 0x02 // rsc eq r3 r13 0x003fc000
};
const byte kInstruction_rsc_le_r15_r4_0x2ac00000[] = {
  0xab, 0xf5, 0xe4, 0xd2 // rsc le r15 r4 0x2ac00000
};
const byte kInstruction_rsc_le_r15_r4_0x03fc0000[] = {
  0xff, 0xf7, 0xe4, 0xd2 // rsc le r15 r4 0x03fc0000
};
const byte kInstruction_rsc_hi_r4_r15_0xc000002a[] = {
  0xab, 0x41, 0xef, 0x82 // rsc hi r4 r15 0xc000002a
};
const byte kInstruction_rsc_ge_r8_r15_0xac000002[] = {
  0xab, 0x83, 0xef, 0xa2 // rsc ge r8 r15 0xac000002
};
const byte kInstruction_rsc_pl_r10_r7_0x002ac000[] = {
  0xab, 0xa9, 0xe7, 0x52 // rsc pl r10 r7 0x002ac000
};
const byte kInstruction_rsc_vs_r14_r1_0x000000ff[] = {
  0xff, 0xe0, 0xe1, 0x62 // rsc vs r14 r1 0x000000ff
};
const byte kInstruction_rsc_hi_r4_r4_0x00000ab0[] = {
  0xab, 0x4e, 0xe4, 0x82 // rsc hi r4 r4 0x00000ab0
};
const byte kInstruction_rsc_gt_r0_r2_0xac000002[] = {
  0xab, 0x03, 0xe2, 0xc2 // rsc gt r0 r2 0xac000002
};
const byte kInstruction_rsc_ls_r10_r1_0x000ab000[] = {
  0xab, 0xaa, 0xe1, 0x92 // rsc ls r10 r1 0x000ab000
};
const byte kInstruction_rsc_ge_r9_r4_0xc000003f[] = {
  0xff, 0x91, 0xe4, 0xa2 // rsc ge r9 r4 0xc000003f
};
const byte kInstruction_rsc_eq_r12_r13_0x000ab000[] = {
  0xab, 0xca, 0xed, 0x02 // rsc eq r12 r13 0x000ab000
};
const byte kInstruction_rsc_eq_r8_r5_0x0003fc00[] = {
  0xff, 0x8b, 0xe5, 0x02 // rsc eq r8 r5 0x0003fc00
};
const byte kInstruction_rsc_lt_r1_r1_0x0002ac00[] = {
  0xab, 0x1b, 0xe1, 0xb2 // rsc lt r1 r1 0x0002ac00
};
const byte kInstruction_rsc_lt_r14_r14_0x00000ff0[] = {
  0xff, 0xee, 0xee, 0xb2 // rsc lt r14 r14 0x00000ff0
};
const byte kInstruction_rsc_gt_r0_r7_0x000ff000[] = {
  0xff, 0x0a, 0xe7, 0xc2 // rsc gt r0 r7 0x000ff000
};
const byte kInstruction_rsc_eq_r7_r13_0x0002ac00[] = {
  0xab, 0x7b, 0xed, 0x02 // rsc eq r7 r13 0x0002ac00
};
const byte kInstruction_rsc_le_r4_r9_0x0000ff00[] = {
  0xff, 0x4c, 0xe9, 0xd2 // rsc le r4 r9 0x0000ff00
};
const byte kInstruction_rsc_le_r4_r12_0xab000000[] = {
  0xab, 0x44, 0xec, 0xd2 // rsc le r4 r12 0xab000000
};
const byte kInstruction_rsc_mi_r1_r8_0x02ac0000[] = {
  0xab, 0x17, 0xe8, 0x42 // rsc mi r1 r8 0x02ac0000
};
const byte kInstruction_rsc_al_r9_r11_0xc000003f[] = {
  0xff, 0x91, 0xeb, 0xe2 // rsc al r9 r11 0xc000003f
};
const byte kInstruction_rsc_cs_r13_r4_0x0ff00000[] = {
  0xff, 0xd6, 0xe4, 0x22 // rsc cs r13 r4 0x0ff00000
};
const byte kInstruction_rsc_lt_r14_r11_0x0000ff00[] = {
  0xff, 0xec, 0xeb, 0xb2 // rsc lt r14 r11 0x0000ff00
};
const byte kInstruction_rsc_cc_r2_r13_0x3fc00000[] = {
  0xff, 0x25, 0xed, 0x32 // rsc cc r2 r13 0x3fc00000
};
const byte kInstruction_rsc_lt_r4_r2_0xc000002a[] = {
  0xab, 0x41, 0xe2, 0xb2 // rsc lt r4 r2 0xc000002a
};
const byte kInstruction_rsc_vs_r9_r14_0x00002ac0[] = {
  0xab, 0x9d, 0xee, 0x62 // rsc vs r9 r14 0x00002ac0
};
const byte kInstruction_rsc_eq_r1_r5_0xc000002a[] = {
  0xab, 0x11, 0xe5, 0x02 // rsc eq r1 r5 0xc000002a
};
const byte kInstruction_rsc_vc_r12_r5_0x000003fc[] = {
  0xff, 0xcf, 0xe5, 0x72 // rsc vc r12 r5 0x000003fc
};
const byte kInstruction_rsc_mi_r12_r4_0xfc000003[] = {
  0xff, 0xc3, 0xe4, 0x42 // rsc mi r12 r4 0xfc000003
};
const byte kInstruction_rsc_cc_r4_r15_0x02ac0000[] = {
  0xab, 0x47, 0xef, 0x32 // rsc cc r4 r15 0x02ac0000
};
const byte kInstruction_rsc_ls_r5_r10_0x0000ab00[] = {
  0xab, 0x5c, 0xea, 0x92 // rsc ls r5 r10 0x0000ab00
};
const byte kInstruction_rsc_cc_r9_r9_0x000003fc[] = {
  0xff, 0x9f, 0xe9, 0x32 // rsc cc r9 r9 0x000003fc
};
const byte kInstruction_rsc_pl_r5_r13_0xff000000[] = {
  0xff, 0x54, 0xed, 0x52 // rsc pl r5 r13 0xff000000
};
const byte kInstruction_rsc_al_r0_r1_0xac000002[] = {
  0xab, 0x03, 0xe1, 0xe2 // rsc al r0 r1 0xac000002
};
const byte kInstruction_rsc_al_r12_r13_0x00ff0000[] = {
  0xff, 0xc8, 0xed, 0xe2 // rsc al r12 r13 0x00ff0000
};
const byte kInstruction_rsc_hi_r6_r2_0x000ff000[] = {
  0xff, 0x6a, 0xe2, 0x82 // rsc hi r6 r2 0x000ff000
};
const byte kInstruction_rsc_gt_r13_r9_0x000000ab[] = {
  0xab, 0xd0, 0xe9, 0xc2 // rsc gt r13 r9 0x000000ab
};
const byte kInstruction_rsc_hi_r14_r7_0x0002ac00[] = {
  0xab, 0xeb, 0xe7, 0x82 // rsc hi r14 r7 0x0002ac00
};
const byte kInstruction_rsc_lt_r4_r10_0xb000000a[] = {
  0xab, 0x42, 0xea, 0xb2 // rsc lt r4 r10 0xb000000a
};
const byte kInstruction_rsc_cs_r1_r14_0x00000ff0[] = {
  0xff, 0x1e, 0xee, 0x22 // rsc cs r1 r14 0x00000ff0
};
const byte kInstruction_rsc_hi_r15_r8_0x0002ac00[] = {
  0xab, 0xfb, 0xe8, 0x82 // rsc hi r15 r8 0x0002ac00
};
const byte kInstruction_rsc_cs_r4_r10_0x000000ab[] = {
  0xab, 0x40, 0xea, 0x22 // rsc cs r4 r10 0x000000ab
};
const byte kInstruction_rsc_gt_r0_r9_0x2ac00000[] = {
  0xab, 0x05, 0xe9, 0xc2 // rsc gt r0 r9 0x2ac00000
};
const byte kInstruction_rsc_cc_r2_r6_0x0000ab00[] = {
  0xab, 0x2c, 0xe6, 0x32 // rsc cc r2 r6 0x0000ab00
};
const byte kInstruction_rsc_mi_r3_r9_0x0000ff00[] = {
  0xff, 0x3c, 0xe9, 0x42 // rsc mi r3 r9 0x0000ff00
};
const byte kInstruction_rsc_lt_r6_r13_0xc000002a[] = {
  0xab, 0x61, 0xed, 0xb2 // rsc lt r6 r13 0xc000002a
};
const byte kInstruction_rsc_pl_r7_r7_0x003fc000[] = {
  0xff, 0x79, 0xe7, 0x52 // rsc pl r7 r7 0x003fc000
};
const byte kInstruction_rsc_cc_r1_r6_0x003fc000[] = {
  0xff, 0x19, 0xe6, 0x32 // rsc cc r1 r6 0x003fc000
};
const byte kInstruction_rsc_le_r9_r11_0x000ff000[] = {
  0xff, 0x9a, 0xeb, 0xd2 // rsc le r9 r11 0x000ff000
};
const byte kInstruction_rsc_pl_r4_r7_0xb000000a[] = {
  0xab, 0x42, 0xe7, 0x52 // rsc pl r4 r7 0xb000000a
};
const byte kInstruction_rsc_al_r15_r5_0x0000ff00[] = {
  0xff, 0xfc, 0xe5, 0xe2 // rsc al r15 r5 0x0000ff00
};
const byte kInstruction_rsc_al_r11_r10_0x00ff0000[] = {
  0xff, 0xb8, 0xea, 0xe2 // rsc al r11 r10 0x00ff0000
};
const byte kInstruction_rsc_pl_r9_r5_0x00003fc0[] = {
  0xff, 0x9d, 0xe5, 0x52 // rsc pl r9 r5 0x00003fc0
};
const byte kInstruction_rsc_ls_r6_r11_0xc000003f[] = {
  0xff, 0x61, 0xeb, 0x92 // rsc ls r6 r11 0xc000003f
};
const byte kInstruction_rsc_ge_r9_r15_0x0ab00000[] = {
  0xab, 0x96, 0xef, 0xa2 // rsc ge r9 r15 0x0ab00000
};
const byte kInstruction_rsc_le_r9_r10_0x2ac00000[] = {
  0xab, 0x95, 0xea, 0xd2 // rsc le r9 r10 0x2ac00000
};
const byte kInstruction_rsc_ne_r0_r3_0x00002ac0[] = {
  0xab, 0x0d, 0xe3, 0x12 // rsc ne r0 r3 0x00002ac0
};
const byte kInstruction_rsc_gt_r13_r15_0x00003fc0[] = {
  0xff, 0xdd, 0xef, 0xc2 // rsc gt r13 r15 0x00003fc0
};
const byte kInstruction_rsc_ls_r4_r4_0x00000000[] = {
  0x00, 0x40, 0xe4, 0x92 // rsc ls r4 r4 0x00000000
};
const byte kInstruction_rsc_hi_r6_r8_0xff000000[] = {
  0xff, 0x64, 0xe8, 0x82 // rsc hi r6 r8 0xff000000
};
const byte kInstruction_rsc_cc_r11_r5_0x0003fc00[] = {
  0xff, 0xbb, 0xe5, 0x32 // rsc cc r11 r5 0x0003fc00
};
const byte kInstruction_rsc_vs_r5_r0_0x00002ac0[] = {
  0xab, 0x5d, 0xe0, 0x62 // rsc vs r5 r0 0x00002ac0
};
const byte kInstruction_rsc_vs_r1_r12_0x0000ff00[] = {
  0xff, 0x1c, 0xec, 0x62 // rsc vs r1 r12 0x0000ff00
};
const TestResult kReferencersc[] = {
  {
    ARRAY_SIZE(kInstruction_rsc_le_r9_r4_0x03fc0000),
    kInstruction_rsc_le_r9_r4_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r14_r3_0x0003fc00),
    kInstruction_rsc_pl_r14_r3_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r1_r6_0x3fc00000),
    kInstruction_rsc_cc_r1_r6_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r5_r1_0x02ac0000),
    kInstruction_rsc_cc_r5_r1_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r14_r4_0xb000000a),
    kInstruction_rsc_pl_r14_r4_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r2_r13_0x0003fc00),
    kInstruction_rsc_cs_r2_r13_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r13_r0_0x2ac00000),
    kInstruction_rsc_mi_r13_r0_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r0_r0_0x000ff000),
    kInstruction_rsc_vc_r0_r0_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r2_r9_0x00000ff0),
    kInstruction_rsc_vs_r2_r9_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r15_r7_0x000000ff),
    kInstruction_rsc_cc_r15_r7_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r4_r1_0x0003fc00),
    kInstruction_rsc_ls_r4_r1_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r13_r11_0x3fc00000),
    kInstruction_rsc_gt_r13_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r3_r15_0x2ac00000),
    kInstruction_rsc_hi_r3_r15_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r7_r12_0x02ac0000),
    kInstruction_rsc_ls_r7_r12_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r10_r11_0x00ab0000),
    kInstruction_rsc_cc_r10_r11_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r3_r9_0x03fc0000),
    kInstruction_rsc_mi_r3_r9_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r8_r7_0x000ff000),
    kInstruction_rsc_gt_r8_r7_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r1_r2_0x00ab0000),
    kInstruction_rsc_ls_r1_r2_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r12_r5_0x00002ac0),
    kInstruction_rsc_al_r12_r5_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r15_r5_0x000003fc),
    kInstruction_rsc_eq_r15_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r11_r9_0x000000ab),
    kInstruction_rsc_hi_r11_r9_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r10_r7_0x00ab0000),
    kInstruction_rsc_cs_r10_r7_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r3_r7_0x02ac0000),
    kInstruction_rsc_gt_r3_r7_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r0_r0_0x00ab0000),
    kInstruction_rsc_le_r0_r0_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r15_r4_0x000000ab),
    kInstruction_rsc_hi_r15_r4_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r4_r13_0xab000000),
    kInstruction_rsc_cc_r4_r13_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r12_r2_0x0ab00000),
    kInstruction_rsc_al_r12_r2_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r8_r1_0x000ff000),
    kInstruction_rsc_cc_r8_r1_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r1_r1_0x000ff000),
    kInstruction_rsc_le_r1_r1_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r3_r1_0xff000000),
    kInstruction_rsc_gt_r3_r1_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r4_r2_0x3fc00000),
    kInstruction_rsc_ge_r4_r2_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r8_r7_0xac000002),
    kInstruction_rsc_cc_r8_r7_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r9_r4_0xb000000a),
    kInstruction_rsc_vs_r9_r4_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r11_r5_0x000000ab),
    kInstruction_rsc_cs_r11_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r4_r2_0xb000000a),
    kInstruction_rsc_eq_r4_r2_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r5_r14_0x000000ab),
    kInstruction_rsc_lt_r5_r14_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r2_r4_0x0000ab00),
    kInstruction_rsc_cs_r2_r4_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r5_r9_0x003fc000),
    kInstruction_rsc_hi_r5_r9_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r0_r2_0xb000000a),
    kInstruction_rsc_al_r0_r2_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r13_r0_0x0ff00000),
    kInstruction_rsc_le_r13_r0_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r9_r5_0xb000000a),
    kInstruction_rsc_eq_r9_r5_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r15_r8_0x00ab0000),
    kInstruction_rsc_cc_r15_r8_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r4_r3_0x003fc000),
    kInstruction_rsc_ge_r4_r3_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r15_r1_0x000002ac),
    kInstruction_rsc_hi_r15_r1_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r10_r8_0x000002ac),
    kInstruction_rsc_al_r10_r8_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r3_r5_0xc000003f),
    kInstruction_rsc_al_r3_r5_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r1_r8_0x000000ff),
    kInstruction_rsc_cc_r1_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r8_r4_0x003fc000),
    kInstruction_rsc_vs_r8_r4_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r2_r2_0x003fc000),
    kInstruction_rsc_vc_r2_r2_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r1_r1_0x03fc0000),
    kInstruction_rsc_hi_r1_r1_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r6_r12_0x00000000),
    kInstruction_rsc_cc_r6_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r8_r1_0xc000002a),
    kInstruction_rsc_hi_r8_r1_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r7_r12_0x003fc000),
    kInstruction_rsc_ge_r7_r12_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r1_r14_0x02ac0000),
    kInstruction_rsc_gt_r1_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r4_r0_0x0ff00000),
    kInstruction_rsc_eq_r4_r0_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r6_r10_0x00000ab0),
    kInstruction_rsc_vs_r6_r10_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r4_r8_0x03fc0000),
    kInstruction_rsc_eq_r4_r8_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r8_r13_0x002ac000),
    kInstruction_rsc_lt_r8_r13_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r1_r5_0x000003fc),
    kInstruction_rsc_mi_r1_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r8_r1_0x00ab0000),
    kInstruction_rsc_ge_r8_r1_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r0_r8_0xb000000a),
    kInstruction_rsc_al_r0_r8_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r3_r0_0x0000ff00),
    kInstruction_rsc_cs_r3_r0_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r14_r6_0x03fc0000),
    kInstruction_rsc_le_r14_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r13_r7_0xab000000),
    kInstruction_rsc_lt_r13_r7_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r7_r7_0x00ff0000),
    kInstruction_rsc_vc_r7_r7_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r8_r1_0x0ab00000),
    kInstruction_rsc_ls_r8_r1_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r10_r12_0x000002ac),
    kInstruction_rsc_lt_r10_r12_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r11_r0_0x3fc00000),
    kInstruction_rsc_ls_r11_r0_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r9_r8_0x002ac000),
    kInstruction_rsc_ge_r9_r8_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r5_r2_0x02ac0000),
    kInstruction_rsc_vc_r5_r2_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r2_r9_0x0ff00000),
    kInstruction_rsc_gt_r2_r9_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r10_r6_0x2ac00000),
    kInstruction_rsc_eq_r10_r6_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r0_r9_0xfc000003),
    kInstruction_rsc_ls_r0_r9_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r15_r12_0x02ac0000),
    kInstruction_rsc_eq_r15_r12_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r3_r1_0xfc000003),
    kInstruction_rsc_mi_r3_r1_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r0_r0_0xb000000a),
    kInstruction_rsc_lt_r0_r0_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r14_r8_0xff000000),
    kInstruction_rsc_cs_r14_r8_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r7_r1_0x00003fc0),
    kInstruction_rsc_lt_r7_r1_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r8_r1_0x00000ff0),
    kInstruction_rsc_ls_r8_r1_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r15_r3_0x0002ac00),
    kInstruction_rsc_cc_r15_r3_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r15_r0_0xc000003f),
    kInstruction_rsc_cs_r15_r0_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r4_r2_0x0002ac00),
    kInstruction_rsc_hi_r4_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r10_r12_0x0003fc00),
    kInstruction_rsc_ne_r10_r12_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r7_r13_0x00003fc0),
    kInstruction_rsc_gt_r7_r13_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r14_r4_0xac000002),
    kInstruction_rsc_vc_r14_r4_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r13_r7_0x00000000),
    kInstruction_rsc_le_r13_r7_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r5_r15_0x00000ab0),
    kInstruction_rsc_pl_r5_r15_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r1_r1_0x03fc0000),
    kInstruction_rsc_vs_r1_r1_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r4_r4_0xab000000),
    kInstruction_rsc_le_r4_r4_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r11_r4_0x0ff00000),
    kInstruction_rsc_gt_r11_r4_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r1_r3_0x0000ab00),
    kInstruction_rsc_cc_r1_r3_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r10_r9_0x0000ab00),
    kInstruction_rsc_cs_r10_r9_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r7_r5_0x00ab0000),
    kInstruction_rsc_vc_r7_r5_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r4_r1_0x0000ab00),
    kInstruction_rsc_cc_r4_r1_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r4_r15_0xfc000003),
    kInstruction_rsc_hi_r4_r15_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r11_r1_0xff000000),
    kInstruction_rsc_eq_r11_r1_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r4_r2_0x00002ac0),
    kInstruction_rsc_gt_r4_r2_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r10_r10_0x000000ff),
    kInstruction_rsc_ls_r10_r10_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r11_r10_0x00ff0000),
    kInstruction_rsc_gt_r11_r10_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r12_r6_0x00000ff0),
    kInstruction_rsc_ls_r12_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r9_r4_0xb000000a),
    kInstruction_rsc_vc_r9_r4_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r10_r13_0x00003fc0),
    kInstruction_rsc_hi_r10_r13_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r6_r4_0xab000000),
    kInstruction_rsc_vc_r6_r4_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r1_r4_0x0ff00000),
    kInstruction_rsc_gt_r1_r4_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r8_r0_0x00003fc0),
    kInstruction_rsc_ne_r8_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r13_r9_0x0002ac00),
    kInstruction_rsc_ls_r13_r9_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r8_r8_0xfc000003),
    kInstruction_rsc_eq_r8_r8_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r4_r3_0x0002ac00),
    kInstruction_rsc_pl_r4_r3_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r3_r1_0xab000000),
    kInstruction_rsc_cc_r3_r1_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r13_r3_0xc000002a),
    kInstruction_rsc_cc_r13_r3_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r10_r14_0x00000000),
    kInstruction_rsc_cc_r10_r14_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r13_r6_0x000ff000),
    kInstruction_rsc_hi_r13_r6_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r7_r15_0x0002ac00),
    kInstruction_rsc_ge_r7_r15_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r1_r11_0x0002ac00),
    kInstruction_rsc_le_r1_r11_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r12_r1_0x02ac0000),
    kInstruction_rsc_gt_r12_r1_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r0_r12_0x00002ac0),
    kInstruction_rsc_hi_r0_r12_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r6_r9_0xfc000003),
    kInstruction_rsc_lt_r6_r9_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r6_r6_0x0002ac00),
    kInstruction_rsc_ls_r6_r6_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r12_r3_0xab000000),
    kInstruction_rsc_vc_r12_r3_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r12_r10_0x0ab00000),
    kInstruction_rsc_pl_r12_r10_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r9_r11_0xff000000),
    kInstruction_rsc_lt_r9_r11_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r1_r11_0x00000ff0),
    kInstruction_rsc_pl_r1_r11_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r10_r3_0x00003fc0),
    kInstruction_rsc_cs_r10_r3_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r1_r12_0x03fc0000),
    kInstruction_rsc_vs_r1_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r2_r2_0xf000000f),
    kInstruction_rsc_ls_r2_r2_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r11_r4_0x0003fc00),
    kInstruction_rsc_pl_r11_r4_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r13_r7_0x03fc0000),
    kInstruction_rsc_cc_r13_r7_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r5_r1_0x00ab0000),
    kInstruction_rsc_hi_r5_r1_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r8_r5_0x0ab00000),
    kInstruction_rsc_eq_r8_r5_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r6_r15_0x0002ac00),
    kInstruction_rsc_ge_r6_r15_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r5_r6_0x00000ff0),
    kInstruction_rsc_ls_r5_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r13_r11_0x000003fc),
    kInstruction_rsc_gt_r13_r11_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r8_r6_0xc000002a),
    kInstruction_rsc_vc_r8_r6_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r10_r2_0x000000ab),
    kInstruction_rsc_ge_r10_r2_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r7_r14_0x000000ab),
    kInstruction_rsc_pl_r7_r14_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r11_r10_0x3fc00000),
    kInstruction_rsc_vc_r11_r10_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r9_r0_0x00003fc0),
    kInstruction_rsc_pl_r9_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r15_r1_0x000ab000),
    kInstruction_rsc_hi_r15_r1_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r3_r4_0x00ab0000),
    kInstruction_rsc_gt_r3_r4_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r7_r12_0x00000ab0),
    kInstruction_rsc_cs_r7_r12_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r3_r8_0x0ff00000),
    kInstruction_rsc_vs_r3_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r12_r8_0x000000ff),
    kInstruction_rsc_cc_r12_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r1_r5_0x02ac0000),
    kInstruction_rsc_vc_r1_r5_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r7_r12_0xf000000f),
    kInstruction_rsc_cc_r7_r12_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r9_r4_0x0000ab00),
    kInstruction_rsc_gt_r9_r4_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r14_r8_0x0ff00000),
    kInstruction_rsc_pl_r14_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r8_r4_0x000003fc),
    kInstruction_rsc_vc_r8_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r1_r15_0xb000000a),
    kInstruction_rsc_cc_r1_r15_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r15_r11_0x000ff000),
    kInstruction_rsc_al_r15_r11_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r1_r13_0x00002ac0),
    kInstruction_rsc_ls_r1_r13_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r4_r10_0x03fc0000),
    kInstruction_rsc_le_r4_r10_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r2_r4_0x00000ab0),
    kInstruction_rsc_mi_r2_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r13_r6_0x02ac0000),
    kInstruction_rsc_al_r13_r6_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r7_r9_0x000002ac),
    kInstruction_rsc_mi_r7_r9_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r9_r7_0x00002ac0),
    kInstruction_rsc_hi_r9_r7_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r15_r9_0x0000ab00),
    kInstruction_rsc_vc_r15_r9_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r13_r0_0xff000000),
    kInstruction_rsc_vc_r13_r0_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r15_r10_0x00003fc0),
    kInstruction_rsc_cc_r15_r10_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r12_r2_0x00000ab0),
    kInstruction_rsc_lt_r12_r2_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r1_r3_0xb000000a),
    kInstruction_rsc_le_r1_r3_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r14_r12_0xc000002a),
    kInstruction_rsc_hi_r14_r12_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r5_r8_0x000ff000),
    kInstruction_rsc_vc_r5_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r12_r9_0x000000ab),
    kInstruction_rsc_gt_r12_r9_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r13_r7_0xf000000f),
    kInstruction_rsc_al_r13_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r3_r10_0x000002ac),
    kInstruction_rsc_ls_r3_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r13_r13_0x00000ab0),
    kInstruction_rsc_ne_r13_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r15_r3_0xfc000003),
    kInstruction_rsc_ge_r15_r3_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r7_r0_0x0003fc00),
    kInstruction_rsc_cc_r7_r0_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r3_r14_0x2ac00000),
    kInstruction_rsc_eq_r3_r14_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r11_r14_0x003fc000),
    kInstruction_rsc_al_r11_r14_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r3_r12_0x02ac0000),
    kInstruction_rsc_gt_r3_r12_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r7_r15_0xac000002),
    kInstruction_rsc_mi_r7_r15_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r3_r2_0x002ac000),
    kInstruction_rsc_al_r3_r2_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r2_r6_0x0002ac00),
    kInstruction_rsc_hi_r2_r6_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r8_r5_0x03fc0000),
    kInstruction_rsc_eq_r8_r5_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r2_r13_0x0002ac00),
    kInstruction_rsc_hi_r2_r13_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r10_r10_0x00ab0000),
    kInstruction_rsc_lt_r10_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r12_r3_0x0ab00000),
    kInstruction_rsc_al_r12_r3_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r1_r2_0x003fc000),
    kInstruction_rsc_ls_r1_r2_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r9_r10_0x000ff000),
    kInstruction_rsc_le_r9_r10_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r4_r12_0x00000000),
    kInstruction_rsc_vc_r4_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r7_r7_0x02ac0000),
    kInstruction_rsc_pl_r7_r7_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r6_r11_0x02ac0000),
    kInstruction_rsc_ge_r6_r11_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r10_r4_0x000000ff),
    kInstruction_rsc_ls_r10_r4_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r12_r4_0x00000ff0),
    kInstruction_rsc_cc_r12_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r6_r3_0x0ff00000),
    kInstruction_rsc_gt_r6_r3_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r3_r10_0x00ab0000),
    kInstruction_rsc_cc_r3_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r6_r7_0x00ab0000),
    kInstruction_rsc_eq_r6_r7_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r3_r3_0x003fc000),
    kInstruction_rsc_le_r3_r3_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r11_r3_0x3fc00000),
    kInstruction_rsc_lt_r11_r3_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r11_r2_0x00003fc0),
    kInstruction_rsc_vc_r11_r2_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r11_r11_0x000ff000),
    kInstruction_rsc_ls_r11_r11_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r13_r2_0x0000ff00),
    kInstruction_rsc_eq_r13_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r9_r1_0x00002ac0),
    kInstruction_rsc_vc_r9_r1_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r2_r14_0xfc000003),
    kInstruction_rsc_ne_r2_r14_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r10_r11_0x00002ac0),
    kInstruction_rsc_vs_r10_r11_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r9_r9_0x000002ac),
    kInstruction_rsc_cc_r9_r9_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r9_r3_0x0000ab00),
    kInstruction_rsc_gt_r9_r3_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r3_r0_0x000000ab),
    kInstruction_rsc_ge_r3_r0_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r6_r11_0xb000000a),
    kInstruction_rsc_pl_r6_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r7_r3_0xb000000a),
    kInstruction_rsc_cs_r7_r3_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r0_r8_0x00ff0000),
    kInstruction_rsc_ge_r0_r8_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r9_r0_0x00ab0000),
    kInstruction_rsc_lt_r9_r0_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r8_r0_0xc000003f),
    kInstruction_rsc_cs_r8_r0_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r2_r5_0x03fc0000),
    kInstruction_rsc_eq_r2_r5_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r1_r9_0x0000ab00),
    kInstruction_rsc_ls_r1_r9_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r3_r1_0x00000ab0),
    kInstruction_rsc_al_r3_r1_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r11_r11_0xfc000003),
    kInstruction_rsc_gt_r11_r11_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r9_r8_0x00000ab0),
    kInstruction_rsc_hi_r9_r8_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r6_r10_0xff000000),
    kInstruction_rsc_gt_r6_r10_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r9_r14_0x00003fc0),
    kInstruction_rsc_le_r9_r14_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r11_r0_0xf000000f),
    kInstruction_rsc_cc_r11_r0_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r8_r5_0x000002ac),
    kInstruction_rsc_pl_r8_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r1_r15_0x000ff000),
    kInstruction_rsc_gt_r1_r15_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r1_r2_0x02ac0000),
    kInstruction_rsc_eq_r1_r2_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r8_r7_0x0ff00000),
    kInstruction_rsc_ge_r8_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r15_r14_0x0000ab00),
    kInstruction_rsc_le_r15_r14_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r15_r11_0x00002ac0),
    kInstruction_rsc_al_r15_r11_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r11_r4_0x000002ac),
    kInstruction_rsc_al_r11_r4_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r13_r12_0x000003fc),
    kInstruction_rsc_le_r13_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r15_r8_0x000ff000),
    kInstruction_rsc_al_r15_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r4_r2_0x0002ac00),
    kInstruction_rsc_eq_r4_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r1_r9_0x002ac000),
    kInstruction_rsc_ge_r1_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r12_r5_0x00000000),
    kInstruction_rsc_lt_r12_r5_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r10_r8_0x00000ff0),
    kInstruction_rsc_pl_r10_r8_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r13_r12_0x00ff0000),
    kInstruction_rsc_ge_r13_r12_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r9_r7_0x00000ff0),
    kInstruction_rsc_al_r9_r7_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r6_r3_0x00000000),
    kInstruction_rsc_ls_r6_r3_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r1_r2_0x00002ac0),
    kInstruction_rsc_al_r1_r2_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r4_r12_0x0002ac00),
    kInstruction_rsc_le_r4_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r7_r1_0x0000ff00),
    kInstruction_rsc_ge_r7_r1_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r10_r14_0x3fc00000),
    kInstruction_rsc_le_r10_r14_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r7_r9_0x000000ab),
    kInstruction_rsc_al_r7_r9_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r6_r3_0x000003fc),
    kInstruction_rsc_hi_r6_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r14_r11_0x000000ff),
    kInstruction_rsc_cs_r14_r11_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r0_r15_0xab000000),
    kInstruction_rsc_le_r0_r15_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r0_r3_0xc000002a),
    kInstruction_rsc_ls_r0_r3_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r5_r6_0x000002ac),
    kInstruction_rsc_le_r5_r6_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r5_r9_0xb000000a),
    kInstruction_rsc_eq_r5_r9_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r12_r6_0x000002ac),
    kInstruction_rsc_al_r12_r6_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r11_r10_0x0003fc00),
    kInstruction_rsc_vs_r11_r10_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r8_r5_0x0003fc00),
    kInstruction_rsc_gt_r8_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r1_r9_0x00000000),
    kInstruction_rsc_eq_r1_r9_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r2_r9_0x3fc00000),
    kInstruction_rsc_ge_r2_r9_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r4_r13_0x00ab0000),
    kInstruction_rsc_cs_r4_r13_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r4_r12_0x00ab0000),
    kInstruction_rsc_hi_r4_r12_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r2_r3_0x003fc000),
    kInstruction_rsc_ne_r2_r3_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r0_r11_0xfc000003),
    kInstruction_rsc_vs_r0_r11_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r14_r9_0x003fc000),
    kInstruction_rsc_hi_r14_r9_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r7_r5_0xab000000),
    kInstruction_rsc_vc_r7_r5_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r15_r8_0x002ac000),
    kInstruction_rsc_lt_r15_r8_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r3_r7_0x0003fc00),
    kInstruction_rsc_cs_r3_r7_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r7_r11_0xb000000a),
    kInstruction_rsc_cs_r7_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r0_r11_0xb000000a),
    kInstruction_rsc_ge_r0_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r6_r5_0x0ab00000),
    kInstruction_rsc_vs_r6_r5_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r10_r1_0xfc000003),
    kInstruction_rsc_le_r10_r1_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r3_r6_0x3fc00000),
    kInstruction_rsc_cc_r3_r6_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r12_r14_0x00000ab0),
    kInstruction_rsc_le_r12_r14_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r15_r12_0x00003fc0),
    kInstruction_rsc_al_r15_r12_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r12_r10_0x0000ab00),
    kInstruction_rsc_gt_r12_r10_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r6_r15_0x0ff00000),
    kInstruction_rsc_ls_r6_r15_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r4_r4_0x00003fc0),
    kInstruction_rsc_mi_r4_r4_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r8_r9_0xc000002a),
    kInstruction_rsc_gt_r8_r9_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r10_r4_0x000002ac),
    kInstruction_rsc_le_r10_r4_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r0_r1_0x000003fc),
    kInstruction_rsc_vs_r0_r1_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r1_r5_0x0ff00000),
    kInstruction_rsc_al_r1_r5_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r11_r5_0xc000002a),
    kInstruction_rsc_cc_r11_r5_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r6_r13_0x003fc000),
    kInstruction_rsc_vc_r6_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r1_r15_0x00003fc0),
    kInstruction_rsc_eq_r1_r15_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r15_r10_0x000002ac),
    kInstruction_rsc_lt_r15_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r13_r13_0x003fc000),
    kInstruction_rsc_ne_r13_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r11_r7_0xc000002a),
    kInstruction_rsc_mi_r11_r7_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r6_r2_0x00ff0000),
    kInstruction_rsc_cc_r6_r2_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r9_r1_0x0000ab00),
    kInstruction_rsc_gt_r9_r1_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r11_r7_0x000000ff),
    kInstruction_rsc_le_r11_r7_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r9_r8_0x0002ac00),
    kInstruction_rsc_hi_r9_r8_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r6_r8_0xff000000),
    kInstruction_rsc_vs_r6_r8_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r10_r4_0x000ab000),
    kInstruction_rsc_mi_r10_r4_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r7_r10_0xab000000),
    kInstruction_rsc_ls_r7_r10_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r1_r0_0x00000000),
    kInstruction_rsc_lt_r1_r0_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r2_r13_0x00002ac0),
    kInstruction_rsc_eq_r2_r13_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r14_r13_0x00003fc0),
    kInstruction_rsc_cc_r14_r13_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r9_r4_0x0ab00000),
    kInstruction_rsc_le_r9_r4_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r4_r7_0x00000ab0),
    kInstruction_rsc_gt_r4_r7_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r5_r4_0xc000003f),
    kInstruction_rsc_eq_r5_r4_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r2_r13_0xb000000a),
    kInstruction_rsc_al_r2_r13_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r13_r11_0x2ac00000),
    kInstruction_rsc_le_r13_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r5_r14_0xac000002),
    kInstruction_rsc_gt_r5_r14_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r2_r7_0x000000ab),
    kInstruction_rsc_vs_r2_r7_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r6_r1_0x0ab00000),
    kInstruction_rsc_ne_r6_r1_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r4_r7_0x0000ff00),
    kInstruction_rsc_eq_r4_r7_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r11_r12_0xc000003f),
    kInstruction_rsc_cc_r11_r12_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r7_r9_0x02ac0000),
    kInstruction_rsc_pl_r7_r9_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r5_r4_0x00000000),
    kInstruction_rsc_vc_r5_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r7_r1_0xc000002a),
    kInstruction_rsc_le_r7_r1_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r3_r10_0x2ac00000),
    kInstruction_rsc_cs_r3_r10_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r11_r13_0x00003fc0),
    kInstruction_rsc_le_r11_r13_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r2_r11_0x000000ff),
    kInstruction_rsc_pl_r2_r11_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r14_r11_0x00000000),
    kInstruction_rsc_cs_r14_r11_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r6_r8_0x003fc000),
    kInstruction_rsc_ls_r6_r8_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r6_r8_0xab000000),
    kInstruction_rsc_al_r6_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r4_r2_0x002ac000),
    kInstruction_rsc_cc_r4_r2_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r3_r13_0x003fc000),
    kInstruction_rsc_lt_r3_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r7_r3_0x02ac0000),
    kInstruction_rsc_lt_r7_r3_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r12_r1_0x0000ff00),
    kInstruction_rsc_gt_r12_r1_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r13_r11_0x02ac0000),
    kInstruction_rsc_mi_r13_r11_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r9_r0_0xc000003f),
    kInstruction_rsc_al_r9_r0_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r12_r9_0x00003fc0),
    kInstruction_rsc_mi_r12_r9_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r5_r2_0x3fc00000),
    kInstruction_rsc_ge_r5_r2_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r4_r2_0x002ac000),
    kInstruction_rsc_gt_r4_r2_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r6_r13_0x00003fc0),
    kInstruction_rsc_cs_r6_r13_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r14_r0_0xff000000),
    kInstruction_rsc_ne_r14_r0_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r5_r11_0xc000002a),
    kInstruction_rsc_ls_r5_r11_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r11_r6_0xf000000f),
    kInstruction_rsc_gt_r11_r6_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r11_r5_0x000000ff),
    kInstruction_rsc_ne_r11_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r9_r14_0x0ab00000),
    kInstruction_rsc_eq_r9_r14_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r0_r10_0x0002ac00),
    kInstruction_rsc_cs_r0_r10_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r15_r15_0x00003fc0),
    kInstruction_rsc_ls_r15_r15_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r2_r2_0xc000003f),
    kInstruction_rsc_eq_r2_r2_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r10_r3_0xfc000003),
    kInstruction_rsc_ls_r10_r3_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r9_r2_0x000ab000),
    kInstruction_rsc_gt_r9_r2_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r7_r6_0xb000000a),
    kInstruction_rsc_vc_r7_r6_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r9_r0_0x002ac000),
    kInstruction_rsc_vs_r9_r0_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r10_r8_0x2ac00000),
    kInstruction_rsc_hi_r10_r8_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r15_r6_0x003fc000),
    kInstruction_rsc_vs_r15_r6_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r1_r8_0x2ac00000),
    kInstruction_rsc_cc_r1_r8_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r5_r14_0x000ab000),
    kInstruction_rsc_gt_r5_r14_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r2_r9_0xc000003f),
    kInstruction_rsc_ls_r2_r9_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r1_r10_0x00000000),
    kInstruction_rsc_vs_r1_r10_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r8_r12_0x0ff00000),
    kInstruction_rsc_lt_r8_r12_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r13_r14_0x00002ac0),
    kInstruction_rsc_cc_r13_r14_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r0_r3_0x00003fc0),
    kInstruction_rsc_gt_r0_r3_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r0_r0_0xc000003f),
    kInstruction_rsc_le_r0_r0_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r8_r8_0xff000000),
    kInstruction_rsc_vc_r8_r8_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r0_r5_0x00002ac0),
    kInstruction_rsc_vc_r0_r5_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r3_r10_0x00ff0000),
    kInstruction_rsc_ls_r3_r10_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r5_r2_0x03fc0000),
    kInstruction_rsc_cc_r5_r2_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r13_r8_0xc000002a),
    kInstruction_rsc_ls_r13_r8_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r14_r4_0x3fc00000),
    kInstruction_rsc_vc_r14_r4_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r7_r8_0xac000002),
    kInstruction_rsc_eq_r7_r8_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r13_r13_0x002ac000),
    kInstruction_rsc_al_r13_r13_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r0_r10_0x000ff000),
    kInstruction_rsc_vc_r0_r10_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r11_r12_0x00002ac0),
    kInstruction_rsc_vc_r11_r12_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r15_r4_0x000ff000),
    kInstruction_rsc_mi_r15_r4_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r3_r0_0xfc000003),
    kInstruction_rsc_eq_r3_r0_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r9_r8_0xab000000),
    kInstruction_rsc_mi_r9_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r5_r7_0xc000003f),
    kInstruction_rsc_cc_r5_r7_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r9_r15_0x002ac000),
    kInstruction_rsc_eq_r9_r15_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r7_r5_0x00000ab0),
    kInstruction_rsc_ne_r7_r5_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r15_r12_0x000002ac),
    kInstruction_rsc_eq_r15_r12_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r0_r13_0x00003fc0),
    kInstruction_rsc_cs_r0_r13_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r13_r11_0xac000002),
    kInstruction_rsc_gt_r13_r11_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r4_r10_0x2ac00000),
    kInstruction_rsc_pl_r4_r10_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r3_r13_0xac000002),
    kInstruction_rsc_ne_r3_r13_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r8_r7_0x000002ac),
    kInstruction_rsc_eq_r8_r7_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r7_r6_0xab000000),
    kInstruction_rsc_vs_r7_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r14_r3_0x00003fc0),
    kInstruction_rsc_le_r14_r3_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r3_r5_0x0ab00000),
    kInstruction_rsc_mi_r3_r5_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r9_r1_0x000000ff),
    kInstruction_rsc_lt_r9_r1_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r6_r2_0xff000000),
    kInstruction_rsc_vc_r6_r2_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r8_r3_0xfc000003),
    kInstruction_rsc_mi_r8_r3_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r14_r11_0x000000ab),
    kInstruction_rsc_gt_r14_r11_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r8_r14_0x0000ff00),
    kInstruction_rsc_eq_r8_r14_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r0_r5_0x000002ac),
    kInstruction_rsc_vs_r0_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r15_r15_0x00000ff0),
    kInstruction_rsc_cs_r15_r15_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r3_r0_0x000000ff),
    kInstruction_rsc_le_r3_r0_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r3_r12_0x000002ac),
    kInstruction_rsc_vc_r3_r12_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r15_r9_0x03fc0000),
    kInstruction_rsc_ne_r15_r9_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r8_r14_0x000002ac),
    kInstruction_rsc_ls_r8_r14_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r7_r10_0x03fc0000),
    kInstruction_rsc_eq_r7_r10_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r0_r7_0xab000000),
    kInstruction_rsc_vc_r0_r7_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r3_r11_0xff000000),
    kInstruction_rsc_vc_r3_r11_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r14_r2_0xfc000003),
    kInstruction_rsc_cs_r14_r2_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r3_r11_0x00ff0000),
    kInstruction_rsc_pl_r3_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r6_r1_0x0002ac00),
    kInstruction_rsc_lt_r6_r1_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r15_r1_0xf000000f),
    kInstruction_rsc_al_r15_r1_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r12_r7_0x002ac000),
    kInstruction_rsc_mi_r12_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r9_r3_0x000003fc),
    kInstruction_rsc_vs_r9_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r9_r14_0x000000ff),
    kInstruction_rsc_cc_r9_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r9_r12_0xac000002),
    kInstruction_rsc_ls_r9_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r13_r13_0xfc000003),
    kInstruction_rsc_al_r13_r13_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r14_r1_0x02ac0000),
    kInstruction_rsc_lt_r14_r1_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r8_r15_0x2ac00000),
    kInstruction_rsc_le_r8_r15_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r10_r8_0x0ab00000),
    kInstruction_rsc_al_r10_r8_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r3_r6_0x0000ab00),
    kInstruction_rsc_eq_r3_r6_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r6_r9_0xab000000),
    kInstruction_rsc_cs_r6_r9_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r13_r1_0xfc000003),
    kInstruction_rsc_al_r13_r1_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r4_r15_0x000002ac),
    kInstruction_rsc_ls_r4_r15_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r4_r10_0x003fc000),
    kInstruction_rsc_cs_r4_r10_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r2_r8_0x000ab000),
    kInstruction_rsc_eq_r2_r8_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r12_r2_0x0003fc00),
    kInstruction_rsc_eq_r12_r2_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r12_r10_0x003fc000),
    kInstruction_rsc_vs_r12_r10_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r9_r2_0xab000000),
    kInstruction_rsc_eq_r9_r2_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r6_r7_0x0003fc00),
    kInstruction_rsc_cc_r6_r7_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r8_r15_0x0000ff00),
    kInstruction_rsc_mi_r8_r15_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r2_r1_0x0ff00000),
    kInstruction_rsc_ls_r2_r1_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r12_r12_0x00002ac0),
    kInstruction_rsc_cs_r12_r12_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r1_r12_0x000003fc),
    kInstruction_rsc_hi_r1_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r9_r0_0x000003fc),
    kInstruction_rsc_ls_r9_r0_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r6_r9_0x00ff0000),
    kInstruction_rsc_ne_r6_r9_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r10_r5_0x000000ff),
    kInstruction_rsc_al_r10_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r10_r4_0xf000000f),
    kInstruction_rsc_pl_r10_r4_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r0_r11_0x03fc0000),
    kInstruction_rsc_hi_r0_r11_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r6_r3_0x00002ac0),
    kInstruction_rsc_al_r6_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r12_r13_0x0000ab00),
    kInstruction_rsc_ne_r12_r13_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r13_r8_0x00002ac0),
    kInstruction_rsc_mi_r13_r8_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r13_r2_0x003fc000),
    kInstruction_rsc_ge_r13_r2_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r10_r15_0x00ff0000),
    kInstruction_rsc_pl_r10_r15_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r12_r7_0xff000000),
    kInstruction_rsc_vs_r12_r7_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r1_r3_0xfc000003),
    kInstruction_rsc_cs_r1_r3_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r9_r4_0x000002ac),
    kInstruction_rsc_ne_r9_r4_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r14_r3_0x02ac0000),
    kInstruction_rsc_vs_r14_r3_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r0_r2_0x0ff00000),
    kInstruction_rsc_vs_r0_r2_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r15_r5_0x000000ab),
    kInstruction_rsc_ne_r15_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r9_r13_0x000000ab),
    kInstruction_rsc_vs_r9_r13_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r3_r9_0x0000ff00),
    kInstruction_rsc_al_r3_r9_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r5_r8_0xac000002),
    kInstruction_rsc_cc_r5_r8_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r0_r13_0x00ab0000),
    kInstruction_rsc_ne_r0_r13_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r3_r12_0x000ff000),
    kInstruction_rsc_vs_r3_r12_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r3_r12_0x000003fc),
    kInstruction_rsc_gt_r3_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r1_r1_0x002ac000),
    kInstruction_rsc_ls_r1_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r9_r10_0x2ac00000),
    kInstruction_rsc_lt_r9_r10_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r1_r9_0x00003fc0),
    kInstruction_rsc_hi_r1_r9_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r2_r13_0x00002ac0),
    kInstruction_rsc_ge_r2_r13_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r2_r7_0xc000003f),
    kInstruction_rsc_ls_r2_r7_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r0_r11_0x3fc00000),
    kInstruction_rsc_eq_r0_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r13_r7_0x0000ab00),
    kInstruction_rsc_vc_r13_r7_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r3_r6_0x00002ac0),
    kInstruction_rsc_le_r3_r6_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r3_r11_0x0ab00000),
    kInstruction_rsc_cc_r3_r11_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r9_r11_0x000002ac),
    kInstruction_rsc_ls_r9_r11_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r11_r4_0x00000ff0),
    kInstruction_rsc_ne_r11_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r3_r15_0xfc000003),
    kInstruction_rsc_cc_r3_r15_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r8_r3_0x00003fc0),
    kInstruction_rsc_ne_r8_r3_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r3_r10_0xff000000),
    kInstruction_rsc_vs_r3_r10_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r9_r0_0x000002ac),
    kInstruction_rsc_mi_r9_r0_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r6_r3_0x0003fc00),
    kInstruction_rsc_cc_r6_r3_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r11_r11_0xac000002),
    kInstruction_rsc_ge_r11_r11_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r3_r13_0x003fc000),
    kInstruction_rsc_eq_r3_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r15_r4_0x2ac00000),
    kInstruction_rsc_le_r15_r4_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r15_r4_0x03fc0000),
    kInstruction_rsc_le_r15_r4_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r4_r15_0xc000002a),
    kInstruction_rsc_hi_r4_r15_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r8_r15_0xac000002),
    kInstruction_rsc_ge_r8_r15_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r10_r7_0x002ac000),
    kInstruction_rsc_pl_r10_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r14_r1_0x000000ff),
    kInstruction_rsc_vs_r14_r1_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r4_r4_0x00000ab0),
    kInstruction_rsc_hi_r4_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r0_r2_0xac000002),
    kInstruction_rsc_gt_r0_r2_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r10_r1_0x000ab000),
    kInstruction_rsc_ls_r10_r1_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r9_r4_0xc000003f),
    kInstruction_rsc_ge_r9_r4_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r12_r13_0x000ab000),
    kInstruction_rsc_eq_r12_r13_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r8_r5_0x0003fc00),
    kInstruction_rsc_eq_r8_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r1_r1_0x0002ac00),
    kInstruction_rsc_lt_r1_r1_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r14_r14_0x00000ff0),
    kInstruction_rsc_lt_r14_r14_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r0_r7_0x000ff000),
    kInstruction_rsc_gt_r0_r7_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r7_r13_0x0002ac00),
    kInstruction_rsc_eq_r7_r13_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r4_r9_0x0000ff00),
    kInstruction_rsc_le_r4_r9_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r4_r12_0xab000000),
    kInstruction_rsc_le_r4_r12_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r1_r8_0x02ac0000),
    kInstruction_rsc_mi_r1_r8_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r9_r11_0xc000003f),
    kInstruction_rsc_al_r9_r11_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r13_r4_0x0ff00000),
    kInstruction_rsc_cs_r13_r4_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r14_r11_0x0000ff00),
    kInstruction_rsc_lt_r14_r11_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r2_r13_0x3fc00000),
    kInstruction_rsc_cc_r2_r13_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r4_r2_0xc000002a),
    kInstruction_rsc_lt_r4_r2_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r9_r14_0x00002ac0),
    kInstruction_rsc_vs_r9_r14_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_eq_r1_r5_0xc000002a),
    kInstruction_rsc_eq_r1_r5_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vc_r12_r5_0x000003fc),
    kInstruction_rsc_vc_r12_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r12_r4_0xfc000003),
    kInstruction_rsc_mi_r12_r4_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r4_r15_0x02ac0000),
    kInstruction_rsc_cc_r4_r15_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r5_r10_0x0000ab00),
    kInstruction_rsc_ls_r5_r10_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r9_r9_0x000003fc),
    kInstruction_rsc_cc_r9_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r5_r13_0xff000000),
    kInstruction_rsc_pl_r5_r13_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r0_r1_0xac000002),
    kInstruction_rsc_al_r0_r1_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r12_r13_0x00ff0000),
    kInstruction_rsc_al_r12_r13_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r6_r2_0x000ff000),
    kInstruction_rsc_hi_r6_r2_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r13_r9_0x000000ab),
    kInstruction_rsc_gt_r13_r9_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r14_r7_0x0002ac00),
    kInstruction_rsc_hi_r14_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r4_r10_0xb000000a),
    kInstruction_rsc_lt_r4_r10_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r1_r14_0x00000ff0),
    kInstruction_rsc_cs_r1_r14_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r15_r8_0x0002ac00),
    kInstruction_rsc_hi_r15_r8_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cs_r4_r10_0x000000ab),
    kInstruction_rsc_cs_r4_r10_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r0_r9_0x2ac00000),
    kInstruction_rsc_gt_r0_r9_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r2_r6_0x0000ab00),
    kInstruction_rsc_cc_r2_r6_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_mi_r3_r9_0x0000ff00),
    kInstruction_rsc_mi_r3_r9_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_lt_r6_r13_0xc000002a),
    kInstruction_rsc_lt_r6_r13_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r7_r7_0x003fc000),
    kInstruction_rsc_pl_r7_r7_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r1_r6_0x003fc000),
    kInstruction_rsc_cc_r1_r6_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r9_r11_0x000ff000),
    kInstruction_rsc_le_r9_r11_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r4_r7_0xb000000a),
    kInstruction_rsc_pl_r4_r7_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r15_r5_0x0000ff00),
    kInstruction_rsc_al_r15_r5_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_al_r11_r10_0x00ff0000),
    kInstruction_rsc_al_r11_r10_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_pl_r9_r5_0x00003fc0),
    kInstruction_rsc_pl_r9_r5_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r6_r11_0xc000003f),
    kInstruction_rsc_ls_r6_r11_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ge_r9_r15_0x0ab00000),
    kInstruction_rsc_ge_r9_r15_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_le_r9_r10_0x2ac00000),
    kInstruction_rsc_le_r9_r10_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ne_r0_r3_0x00002ac0),
    kInstruction_rsc_ne_r0_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_gt_r13_r15_0x00003fc0),
    kInstruction_rsc_gt_r13_r15_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_ls_r4_r4_0x00000000),
    kInstruction_rsc_ls_r4_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_hi_r6_r8_0xff000000),
    kInstruction_rsc_hi_r6_r8_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_cc_r11_r5_0x0003fc00),
    kInstruction_rsc_cc_r11_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r5_r0_0x00002ac0),
    kInstruction_rsc_vs_r5_r0_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_rsc_vs_r1_r12_0x0000ff00),
    kInstruction_rsc_vs_r1_r12_0x0000ff00,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_CONST_RSC_A32_H_
